@@ -1,5 +1,9 @@
 <?php
 /**
+ * @copyright Copyright (c) 2016 Bjoern Schiessle <bjoern@schiessle.org>
+ * @copyright Copyright (c) 2017 Lukas Reschke <lukas@statuscode.ch>
+ *
+ * @author Bjoern Schiessle <bjoern@schiessle.org>
  * @author Lukas Reschke <lukas@statuscode.ch>
  *
  * @license GNU AGPL version 3 or any later version
@@ -22,6 +26,12 @@
 $logger = \OC::$server->getLogger();
 $userSession = \OC::$server->getUserSession();
 $groupManager = \OC::$server->getGroupManager();
+$eventDispatcher = \OC::$server->getEventDispatcher();
 
-$auditLogger = new \OCA\Admin_Audit\AuditLogger($logger, $userSession, $groupManager);
+$auditLogger = new \OCA\Admin_Audit\AuditLogger(
+	$logger,
+	$userSession,
+	$groupManager,
+	$eventDispatcher
+);
 $auditLogger->registerHooks();
