@@ -1,11 +1,13 @@
 <?php
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2017 Georg Ehrke
  *
  * @author Joas Schilling <coding@schilljs.com>
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Thomas Citharel <tcit@tcit.fr>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Georg Ehrke <oc.list@georgehrke.com>
  *
  * @license AGPL-3.0
  *
@@ -30,20 +32,26 @@ use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCA\DAV\Connector\Sabre\Principal;
 use OCA\DAV\DAV\Sharing\Backend;
 use OCP\IDBConnection;
+use OCP\IUser;
+use OCP\IUserManager;
+use OCP\Security\ISecureRandom;
 use Sabre\CalDAV\Backend\AbstractBackend;
 use Sabre\CalDAV\Backend\SchedulingSupport;
 use Sabre\CalDAV\Backend\SubscriptionSupport;
 use Sabre\CalDAV\Backend\SyncSupport;
-use Sabre\CalDAV\Plugin;
 use Sabre\CalDAV\Xml\Property\ScheduleCalendarTransp;
 use Sabre\CalDAV\Xml\Property\SupportedCalendarComponentSet;
 use Sabre\DAV;
 use Sabre\DAV\Exception\Forbidden;
+use Sabre\DAV\Exception\NotFound;
 use Sabre\DAV\PropPatch;
 use Sabre\HTTP\URLUtil;
+use Sabre\VObject\Component\VCalendar;
 use Sabre\VObject\DateTimeParser;
 use Sabre\VObject\Reader;
 use Sabre\VObject\Recur\EventIterator;
+use Symfony\Component\EventDispatcher\EventDispatcherInterface;
+use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
  * Class CalDavBackend
@@ -54,6 +62,9 @@ use Sabre\VObject\Recur\EventIterator;
  */
 class CalDavBackend extends AbstractBackend implements SyncSupport, SubscriptionSupport, SchedulingSupport {
 
+	const PERSONAL_CALENDAR_URI = 'personal';
+	const PERSONAL_CALENDAR_NAME = 'Personal';
+
 	/**
 	 * We need to specify a max date, because we need to stop *somewhere*
 	 *
@@ -64,6 +75,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 */
 	const MAX_DATE = '2038-01-01';
 
+	const ACCESS_PUBLIC = 4;
 	const CLASSIFICATION_PUBLIC = 0;
 	const CLASSIFICATION_PRIVATE = 1;
 	const CLASSIFICATION_CONFIDENTIAL = 2;
@@ -99,6 +111,22 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		'{http://calendarserver.org/ns/}subscribed-strip-attachments' => 'stripattachments',
 	];
 
+	/** @var array properties to index */
+	public static $indexProperties = ['CATEGORIES', 'COMMENT', 'DESCRIPTION',
+		'LOCATION', 'RESOURCES', 'STATUS', 'SUMMARY', 'ATTENDEE', 'CONTACT',
+		'ORGANIZER'];
+
+	/** @var array parameters to index */
+	public static $indexParameters = [
+		'ATTENDEE' => ['CN'],
+		'ORGANIZER' => ['CN'],
+	];
+
+	/**
+	 * @var string[] Map of uid => display name
+	 */
+	protected $userDisplayNames;
+
 	/** @var IDBConnection */
 	private $db;
 
@@ -108,16 +136,67 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	/** @var Principal */
 	private $principalBackend;
 
+	/** @var IUserManager */
+	private $userManager;
+
+	/** @var ISecureRandom */
+	private $random;
+
+	/** @var EventDispatcherInterface */
+	private $dispatcher;
+
+	/** @var bool */
+	private $legacyEndpoint;
+
+	/** @var string */
+	private $dbObjectPropertiesTable = 'calendarobjects_props';
+
 	/**
 	 * CalDavBackend constructor.
 	 *
 	 * @param IDBConnection $db
 	 * @param Principal $principalBackend
+	 * @param IUserManager $userManager
+	 * @param ISecureRandom $random
+	 * @param EventDispatcherInterface $dispatcher
+	 * @param bool $legacyEndpoint
 	 */
-	public function __construct(IDBConnection $db, Principal $principalBackend) {
+	public function __construct(IDBConnection $db,
+								Principal $principalBackend,
+								IUserManager $userManager,
+								ISecureRandom $random,
+								EventDispatcherInterface $dispatcher,
+								$legacyEndpoint = false) {
 		$this->db = $db;
 		$this->principalBackend = $principalBackend;
+		$this->userManager = $userManager;
 		$this->sharingBackend = new Backend($this->db, $principalBackend, 'calendar');
+		$this->random = $random;
+		$this->dispatcher = $dispatcher;
+		$this->legacyEndpoint = $legacyEndpoint;
+	}
+
+	/**
+	 * Return the number of calendars for a principal
+	 *
+	 * By default this excludes the automatically generated birthday calendar
+	 *
+	 * @param $principalUri
+	 * @param bool $excludeBirthday
+	 * @return int
+	 */
+	public function getCalendarsForUserCount($principalUri, $excludeBirthday = true) {
+		$principalUri = $this->convertPrincipal($principalUri, true);
+		$query = $this->db->getQueryBuilder();
+		$query->select($query->createFunction('COUNT(*)'))
+			->from('calendars')
+			->where($query->expr()->eq('principaluri', $query->createNamedParameter($principalUri)));
+
+		if ($excludeBirthday) {
+			$query->andWhere($query->expr()->neq('uri', $query->createNamedParameter(BirthdayService::BIRTHDAY_CALENDAR_URI)));
+		}
+
+		return (int)$query->execute()->fetchColumn();
 	}
 
 	/**
@@ -174,17 +253,20 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$calendar = [
 				'id' => $row['id'],
 				'uri' => $row['uri'],
-				'principaluri' => $this->convertPrincipal($row['principaluri'], false),
+				'principaluri' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
 				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
 				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($principalUri, !$this->legacyEndpoint),
 			];
 
 			foreach($this->propertyMap as $xmlName=>$dbName) {
 				$calendar[$xmlName] = $row[$dbName];
 			}
 
+			$this->addOwnerPrincipal($calendar);
+
 			if (!isset($calendars[$calendar['id']])) {
 				$calendars[$calendar['id']] = $calendar;
 			}
@@ -194,6 +276,9 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 
 		// query for shared calendars
 		$principals = $this->principalBackend->getGroupMembership($principalUriOriginal, true);
+		$principals = array_map(function($principal) {
+			return urldecode($principal);
+		}, $principals);
 		$principals[]= $principalUri;
 
 		$fields = array_values($this->propertyMap);
@@ -214,10 +299,28 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			->setParameter('principaluri', $principals, \Doctrine\DBAL\Connection::PARAM_STR_ARRAY)
 			->execute();
 
+		$readOnlyPropertyName = '{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only';
 		while($row = $result->fetch()) {
+			if ($row['principaluri'] === $principalUri) {
+				continue;
+			}
+
+			$readOnly = (int) $row['access'] === Backend::ACCESS_READ;
+			if (isset($calendars[$row['id']])) {
+				if ($readOnly) {
+					// New share can not have more permissions then the old one.
+					continue;
+				}
+				if (isset($calendars[$row['id']][$readOnlyPropertyName]) &&
+					$calendars[$row['id']][$readOnlyPropertyName] === 0) {
+					// Old share is already read-write, no more permissions can be gained
+					continue;
+				}
+			}
+
 			list(, $name) = URLUtil::splitPath($row['principaluri']);
 			$uri = $row['uri'] . '_shared_by_' . $name;
-			$row['displayname'] = $row['displayname'] . "($name)";
+			$row['displayname'] = $row['displayname'] . ' (' . $this->getUserDisplayName($name) . ')';
 			$components = [];
 			if ($row['components']) {
 				$components = explode(',',$row['components']);
@@ -225,19 +328,135 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$calendar = [
 				'id' => $row['id'],
 				'uri' => $uri,
-				'principaluri' => $principalUri,
+				'principaluri' => $this->convertPrincipal($principalUri, !$this->legacyEndpoint),
 				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
 				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
-				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $row['principaluri'],
-				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
+				$readOnlyPropertyName => $readOnly,
 			];
 
 			foreach($this->propertyMap as $xmlName=>$dbName) {
 				$calendar[$xmlName] = $row[$dbName];
 			}
 
+			$this->addOwnerPrincipal($calendar);
+
+			$calendars[$calendar['id']] = $calendar;
+		}
+		$result->closeCursor();
+
+		return array_values($calendars);
+	}
+
+	public function getUsersOwnCalendars($principalUri) {
+		$principalUri = $this->convertPrincipal($principalUri, true);
+		$fields = array_values($this->propertyMap);
+		$fields[] = 'id';
+		$fields[] = 'uri';
+		$fields[] = 'synctoken';
+		$fields[] = 'components';
+		$fields[] = 'principaluri';
+		$fields[] = 'transparent';
+		// Making fields a comma-delimited list
+		$query = $this->db->getQueryBuilder();
+		$query->select($fields)->from('calendars')
+			->where($query->expr()->eq('principaluri', $query->createNamedParameter($principalUri)))
+			->orderBy('calendarorder', 'ASC');
+		$stmt = $query->execute();
+		$calendars = [];
+		while($row = $stmt->fetch(\PDO::FETCH_ASSOC)) {
+			$components = [];
+			if ($row['components']) {
+				$components = explode(',',$row['components']);
+			}
+			$calendar = [
+				'id' => $row['id'],
+				'uri' => $row['uri'],
+				'principaluri' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
+				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
+				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
+				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+			];
+			foreach($this->propertyMap as $xmlName=>$dbName) {
+				$calendar[$xmlName] = $row[$dbName];
+			}
+
+			$this->addOwnerPrincipal($calendar);
+
+			if (!isset($calendars[$calendar['id']])) {
+				$calendars[$calendar['id']] = $calendar;
+			}
+		}
+		$stmt->closeCursor();
+		return array_values($calendars);
+	}
+
+
+	private function getUserDisplayName($uid) {
+		if (!isset($this->userDisplayNames[$uid])) {
+			$user = $this->userManager->get($uid);
+
+			if ($user instanceof IUser) {
+				$this->userDisplayNames[$uid] = $user->getDisplayName();
+			} else {
+				$this->userDisplayNames[$uid] = $uid;
+			}
+		}
+
+		return $this->userDisplayNames[$uid];
+	}
+	
+	/**
+	 * @return array
+	 */
+	public function getPublicCalendars() {
+		$fields = array_values($this->propertyMap);
+		$fields[] = 'a.id';
+		$fields[] = 'a.uri';
+		$fields[] = 'a.synctoken';
+		$fields[] = 'a.components';
+		$fields[] = 'a.principaluri';
+		$fields[] = 'a.transparent';
+		$fields[] = 's.access';
+		$fields[] = 's.publicuri';
+		$calendars = [];
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select($fields)
+			->from('dav_shares', 's')
+			->join('s', 'calendars', 'a', $query->expr()->eq('s.resourceid', 'a.id'))
+			->where($query->expr()->in('s.access', $query->createNamedParameter(self::ACCESS_PUBLIC)))
+			->andWhere($query->expr()->eq('s.type', $query->createNamedParameter('calendar')))
+			->execute();
+
+		while($row = $result->fetch()) {
+			list(, $name) = URLUtil::splitPath($row['principaluri']);
+			$row['displayname'] = $row['displayname'] . "($name)";
+			$components = [];
+			if ($row['components']) {
+				$components = explode(',',$row['components']);
+			}
+			$calendar = [
+				'id' => $row['id'],
+				'uri' => $row['publicuri'],
+				'principaluri' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
+				'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
+				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+				'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
+				'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri'], $this->legacyEndpoint),
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
+				'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}public' => (int)$row['access'] === self::ACCESS_PUBLIC,
+			];
+
+			foreach($this->propertyMap as $xmlName=>$dbName) {
+				$calendar[$xmlName] = $row[$dbName];
+			}
+
+			$this->addOwnerPrincipal($calendar);
+
 			if (!isset($calendars[$calendar['id']])) {
 				$calendars[$calendar['id']] = $calendar;
 			}
@@ -247,6 +466,67 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return array_values($calendars);
 	}
 
+	/**
+	 * @param string $uri
+	 * @return array
+	 * @throws NotFound
+	 */
+	public function getPublicCalendar($uri) {
+		$fields = array_values($this->propertyMap);
+		$fields[] = 'a.id';
+		$fields[] = 'a.uri';
+		$fields[] = 'a.synctoken';
+		$fields[] = 'a.components';
+		$fields[] = 'a.principaluri';
+		$fields[] = 'a.transparent';
+		$fields[] = 's.access';
+		$fields[] = 's.publicuri';
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select($fields)
+			->from('dav_shares', 's')
+			->join('s', 'calendars', 'a', $query->expr()->eq('s.resourceid', 'a.id'))
+			->where($query->expr()->in('s.access', $query->createNamedParameter(self::ACCESS_PUBLIC)))
+			->andWhere($query->expr()->eq('s.type', $query->createNamedParameter('calendar')))
+			->andWhere($query->expr()->eq('s.publicuri', $query->createNamedParameter($uri)))
+			->execute();
+
+		$row = $result->fetch(\PDO::FETCH_ASSOC);
+
+		$result->closeCursor();
+
+		if ($row === false) {
+			throw new NotFound('Node with name \'' . $uri . '\' could not be found');
+		}
+
+		list(, $name) = URLUtil::splitPath($row['principaluri']);
+		$row['displayname'] = $row['displayname'] . ' ' . "($name)";
+		$components = [];
+		if ($row['components']) {
+			$components = explode(',',$row['components']);
+		}
+		$calendar = [
+			'id' => $row['id'],
+			'uri' => $row['publicuri'],
+			'principaluri' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
+			'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
+			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+			'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
+			'{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' => new ScheduleCalendarTransp($row['transparent']?'transparent':'opaque'),
+			'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
+			'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
+			'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}public' => (int)$row['access'] === self::ACCESS_PUBLIC,
+		];
+
+		foreach($this->propertyMap as $xmlName=>$dbName) {
+			$calendar[$xmlName] = $row[$dbName];
+		}
+
+		$this->addOwnerPrincipal($calendar);
+
+		return $calendar;
+
+	}
+
 	/**
 	 * @param string $principal
 	 * @param string $uri
@@ -283,7 +563,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$calendar = [
 			'id' => $row['id'],
 			'uri' => $row['uri'],
-			'principaluri' => $row['principaluri'],
+			'principaluri' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
 			'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 			'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
@@ -294,6 +574,8 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$calendar[$xmlName] = $row[$dbName];
 		}
 
+		$this->addOwnerPrincipal($calendar);
+
 		return $calendar;
 	}
 
@@ -327,7 +609,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$calendar = [
 			'id' => $row['id'],
 			'uri' => $row['uri'],
-			'principaluri' => $row['principaluri'],
+			'principaluri' => $this->convertPrincipal($row['principaluri'], !$this->legacyEndpoint),
 			'{' . Plugin::NS_CALENDARSERVER . '}getctag' => 'http://sabre.io/ns/sync/' . ($row['synctoken']?$row['synctoken']:'0'),
 			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
 			'{' . Plugin::NS_CALDAV . '}supported-calendar-component-set' => new SupportedCalendarComponentSet($components),
@@ -338,6 +620,8 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$calendar[$xmlName] = $row[$dbName];
 		}
 
+		$this->addOwnerPrincipal($calendar);
+
 		return $calendar;
 	}
 
@@ -354,7 +638,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 */
 	function createCalendar($principalUri, $calendarUri, array $properties) {
 		$values = [
-			'principaluri' => $principalUri,
+			'principaluri' => $this->convertPrincipal($principalUri, true),
 			'uri'          => $calendarUri,
 			'synctoken'    => 1,
 			'transparent'  => 0,
@@ -372,7 +656,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		}
 		$transp = '{' . Plugin::NS_CALDAV . '}schedule-calendar-transp';
 		if (isset($properties[$transp])) {
-			$values['transparent'] = $properties[$transp]->getValue()==='transparent';
+			$values['transparent'] = (int) ($properties[$transp]->getValue() === 'transparent');
 		}
 
 		foreach($this->propertyMap as $xmlName=>$dbName) {
@@ -387,7 +671,16 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			$query->setValue($column, $query->createNamedParameter($value));
 		}
 		$query->execute();
-		return $query->getLastInsertId();
+		$calendarId = $query->getLastInsertId();
+
+		$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::createCalendar', new GenericEvent(
+			'\OCA\DAV\CalDAV\CalDavBackend::createCalendar',
+			[
+				'calendarId' => $calendarId,
+				'calendarData' => $this->getCalendarById($calendarId),
+		]));
+
+		return $calendarId;
 	}
 
 	/**
@@ -416,7 +709,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 				switch ($propertyName) {
 					case '{' . Plugin::NS_CALDAV . '}schedule-calendar-transp' :
 						$fieldName = 'transparent';
-						$newValues[$fieldName] = $propertyValue->getValue() === 'transparent';
+						$newValues[$fieldName] = (int) ($propertyValue->getValue() === 'transparent');
 						break;
 					default :
 						$fieldName = $this->propertyMap[$propertyName];
@@ -435,6 +728,15 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 
 			$this->addChange($calendarId, "", 2);
 
+			$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::updateCalendar', new GenericEvent(
+				'\OCA\DAV\CalDAV\CalDavBackend::updateCalendar',
+				[
+					'calendarId' => $calendarId,
+					'calendarData' => $this->getCalendarById($calendarId),
+					'shares' => $this->getShares($calendarId),
+					'propertyMutations' => $mutations,
+			]));
+
 			return true;
 		});
 	}
@@ -446,6 +748,14 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @return void
 	 */
 	function deleteCalendar($calendarId) {
+		$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::deleteCalendar', new GenericEvent(
+			'\OCA\DAV\CalDAV\CalDavBackend::deleteCalendar',
+			[
+				'calendarId' => $calendarId,
+				'calendarData' => $this->getCalendarById($calendarId),
+				'shares' => $this->getShares($calendarId),
+		]));
+
 		$stmt = $this->db->prepare('DELETE FROM `*PREFIX*calendarobjects` WHERE `calendarid` = ?');
 		$stmt->execute([$calendarId]);
 
@@ -456,6 +766,21 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		$stmt->execute([$calendarId]);
 
 		$this->sharingBackend->deleteAllShares($calendarId);
+
+		$query = $this->db->getQueryBuilder();
+		$query->delete($this->dbObjectPropertiesTable)
+			->where($query->expr()->eq('calendarid', $query->createNamedParameter($calendarId)))
+			->execute();
+	}
+
+	/**
+	 * Delete all of an user's shares
+	 *
+	 * @param string $principaluri
+	 * @return void
+	 */
+	function deleteAllSharesByUser($principaluri) {
+		$this->sharingBackend->deleteAllSharesByUser($principaluri);
 	}
 
 	/**
@@ -623,6 +948,20 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	function createCalendarObject($calendarId, $objectUri, $calendarData) {
 		$extraData = $this->getDenormalizedData($calendarData);
 
+		$q = $this->db->getQueryBuilder();
+		$q->select($q->createFunction('COUNT(*)'))
+			->from('calendarobjects')
+			->where($q->expr()->eq('calendarid', $q->createNamedParameter($calendarId)))
+			->andWhere($q->expr()->eq('uid', $q->createNamedParameter($extraData['uid'])));
+
+		$result = $q->execute();
+		$count = (int) $result->fetchColumn();
+		$result->closeCursor();
+
+		if ($count !== 0) {
+			throw new \Sabre\DAV\Exception\BadRequest('Calendar object with uid already exists in this calendar collection.');
+		}
+
 		$query = $this->db->getQueryBuilder();
 		$query->insert('calendarobjects')
 			->values([
@@ -640,6 +979,17 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			])
 			->execute();
 
+		$this->updateProperties($calendarId, $objectUri, $calendarData);
+
+		$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::createCalendarObject', new GenericEvent(
+			'\OCA\DAV\CalDAV\CalDavBackend::createCalendarObject',
+			[
+				'calendarId' => $calendarId,
+				'calendarData' => $this->getCalendarById($calendarId),
+				'shares' => $this->getShares($calendarId),
+				'objectData' => $this->getCalendarObject($calendarId, $objectUri),
+			]
+		));
 		$this->addChange($calendarId, $objectUri, 1);
 
 		return '"' . $extraData['etag'] . '"';
@@ -681,6 +1031,20 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 			->andWhere($query->expr()->eq('uri', $query->createNamedParameter($objectUri)))
 			->execute();
 
+		$this->updateProperties($calendarId, $objectUri, $calendarData);
+
+		$data = $this->getCalendarObject($calendarId, $objectUri);
+		if (is_array($data)) {
+			$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::updateCalendarObject', new GenericEvent(
+				'\OCA\DAV\CalDAV\CalDavBackend::updateCalendarObject',
+				[
+					'calendarId' => $calendarId,
+					'calendarData' => $this->getCalendarById($calendarId),
+					'shares' => $this->getShares($calendarId),
+					'objectData' => $data,
+				]
+			));
+		}
 		$this->addChange($calendarId, $objectUri, 2);
 
 		return '"' . $extraData['etag'] . '"';
@@ -713,9 +1077,24 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @return void
 	 */
 	function deleteCalendarObject($calendarId, $objectUri) {
+		$data = $this->getCalendarObject($calendarId, $objectUri);
+		if (is_array($data)) {
+			$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::deleteCalendarObject', new GenericEvent(
+				'\OCA\DAV\CalDAV\CalDavBackend::deleteCalendarObject',
+				[
+					'calendarId' => $calendarId,
+					'calendarData' => $this->getCalendarById($calendarId),
+					'shares' => $this->getShares($calendarId),
+					'objectData' => $data,
+				]
+			));
+		}
+
 		$stmt = $this->db->prepare('DELETE FROM `*PREFIX*calendarobjects` WHERE `calendarid` = ? AND `uri` = ?');
 		$stmt->execute([$calendarId, $objectUri]);
 
+		$this->purgeProperties($calendarId, $data['id']);
+
 		$this->addChange($calendarId, $objectUri, 3);
 	}
 
@@ -833,6 +1212,125 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return $result;
 	}
 
+	/**
+	 * custom Nextcloud search extension for CalDAV
+	 *
+	 * @param string $principalUri
+	 * @param array $filters
+	 * @param integer|null $limit
+	 * @param integer|null $offset
+	 * @return array
+	 */
+	public function calendarSearch($principalUri, array $filters, $limit=null, $offset=null) {
+		$calendars = $this->getCalendarsForUser($principalUri);
+		$ownCalendars = [];
+		$sharedCalendars = [];
+
+		$uriMapper = [];
+
+		foreach($calendars as $calendar) {
+			if ($calendar['{http://owncloud.org/ns}owner-principal'] === $principalUri) {
+				$ownCalendars[] = $calendar['id'];
+			} else {
+				$sharedCalendars[] = $calendar['id'];
+			}
+			$uriMapper[$calendar['id']] = $calendar['uri'];
+		}
+		if (count($ownCalendars) === 0 && count($sharedCalendars) === 0) {
+			return [];
+		}
+
+		$query = $this->db->getQueryBuilder();
+		// Calendar id expressions
+		$calendarExpressions = [];
+		foreach($ownCalendars as $id) {
+			$calendarExpressions[] = $query->expr()
+				->eq('c.calendarid', $query->createNamedParameter($id));
+		}
+		foreach($sharedCalendars as $id) {
+			$calendarExpressions[] = $query->expr()->andX(
+				$query->expr()->eq('c.calendarid',
+					$query->createNamedParameter($id)),
+				$query->expr()->eq('c.classification',
+					$query->createNamedParameter(self::CLASSIFICATION_PUBLIC))
+			);
+		}
+
+		if (count($calendarExpressions) === 1) {
+			$calExpr = $calendarExpressions[0];
+		} else {
+			$calExpr = call_user_func_array([$query->expr(), 'orX'], $calendarExpressions);
+		}
+
+		// Component expressions
+		$compExpressions = [];
+		foreach($filters['comps'] as $comp) {
+			$compExpressions[] = $query->expr()
+				->eq('c.componenttype', $query->createNamedParameter($comp));
+		}
+
+		if (count($compExpressions) === 1) {
+			$compExpr = $compExpressions[0];
+		} else {
+			$compExpr = call_user_func_array([$query->expr(), 'orX'], $compExpressions);
+		}
+
+		if (!isset($filters['props'])) {
+			$filters['props'] = [];
+		}
+		if (!isset($filters['params'])) {
+			$filters['params'] = [];
+		}
+
+		$propParamExpressions = [];
+		foreach($filters['props'] as $prop) {
+			$propParamExpressions[] = $query->expr()->andX(
+				$query->expr()->eq('i.name', $query->createNamedParameter($prop)),
+				$query->expr()->isNull('i.parameter')
+			);
+		}
+		foreach($filters['params'] as $param) {
+			$propParamExpressions[] = $query->expr()->andX(
+				$query->expr()->eq('i.name', $query->createNamedParameter($param['property'])),
+				$query->expr()->eq('i.parameter', $query->createNamedParameter($param['parameter']))
+			);
+		}
+
+		if (count($propParamExpressions) === 1) {
+			$propParamExpr = $propParamExpressions[0];
+		} else {
+			$propParamExpr = call_user_func_array([$query->expr(), 'orX'], $propParamExpressions);
+		}
+
+		$query->select(['c.calendarid', 'c.uri'])
+			->from($this->dbObjectPropertiesTable, 'i')
+			->join('i', 'calendarobjects', 'c', $query->expr()->eq('i.objectid', 'c.id'))
+			->where($calExpr)
+			->andWhere($compExpr)
+			->andWhere($propParamExpr)
+			->andWhere($query->expr()->iLike('i.value',
+				$query->createNamedParameter('%'.$this->db->escapeLikeParameter($filters['search-term']).'%')));
+
+		if ($offset) {
+			$query->setFirstResult($offset);
+		}
+		if ($limit) {
+			$query->setMaxResults($limit);
+		}
+
+		$stmt = $query->execute();
+
+		$result = [];
+		while($row = $stmt->fetch(\PDO::FETCH_ASSOC)) {
+			$path = $uriMapper[$row['calendarid']] . '/' . $row['uri'];
+			if (!in_array($path, $result)) {
+				$result[] = $path;
+			}
+		}
+
+		return $result;
+	}
+
 	/**
 	 * Searches through all of a users calendars and calendar objects to find
 	 * an object with a specific UID.
@@ -947,7 +1445,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 
 			$query = "SELECT `uri`, `operation` FROM `*PREFIX*calendarchanges` WHERE `synctoken` >= ? AND `synctoken` < ? AND `calendarid` = ? ORDER BY `synctoken`";
 			if ($limit>0) {
-				$query.= " `LIMIT` " . (int)$limit;
+				$query.= " LIMIT " . (int)$limit;
 			}
 
 			// Fetching all changes
@@ -1361,7 +1859,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 				$it = new EventIterator($vObject, (string)$component->UID);
 				$maxDate = new \DateTime(self::MAX_DATE);
 				if ($it->isInfinite()) {
-					$lastOccurrence = $maxDate->getTimeStamp();
+					$lastOccurrence = $maxDate->getTimestamp();
 				} else {
 					$end = $it->getDtEnd();
 					while($it->valid() && $end < $maxDate) {
@@ -1369,7 +1867,7 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 						$it->next();
 
 					}
-					$lastOccurrence = $end->getTimeStamp();
+					$lastOccurrence = $end->getTimestamp();
 				}
 
 			}
@@ -1412,6 +1910,16 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 	 * @param array $remove
 	 */
 	public function updateShares($shareable, $add, $remove) {
+		$calendarId = $shareable->getResourceId();
+		$this->dispatcher->dispatch('\OCA\DAV\CalDAV\CalDavBackend::updateShares', new GenericEvent(
+			'\OCA\DAV\CalDAV\CalDavBackend::updateShares',
+			[
+				'calendarId' => $calendarId,
+				'calendarData' => $this->getCalendarById($calendarId),
+				'shares' => $this->getShares($calendarId),
+				'add' => $add,
+				'remove' => $remove,
+			]));
 		$this->sharingBackend->updateShares($shareable, $add, $remove);
 	}
 
@@ -1423,6 +1931,50 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return $this->sharingBackend->getShares($resourceId);
 	}
 
+	/**
+	 * @param boolean $value
+	 * @param \OCA\DAV\CalDAV\Calendar $calendar
+	 * @return string|null
+	 */
+	public function setPublishStatus($value, $calendar) {
+		$query = $this->db->getQueryBuilder();
+		if ($value) {
+			$publicUri = $this->random->generate(16, ISecureRandom::CHAR_UPPER.ISecureRandom::CHAR_DIGITS);
+			$query->insert('dav_shares')
+				->values([
+					'principaluri' => $query->createNamedParameter($calendar->getPrincipalURI()),
+					'type' => $query->createNamedParameter('calendar'),
+					'access' => $query->createNamedParameter(self::ACCESS_PUBLIC),
+					'resourceid' => $query->createNamedParameter($calendar->getResourceId()),
+					'publicuri' => $query->createNamedParameter($publicUri)
+				]);
+			$query->execute();
+			return $publicUri;
+		}
+		$query->delete('dav_shares')
+			->where($query->expr()->eq('resourceid', $query->createNamedParameter($calendar->getResourceId())))
+			->andWhere($query->expr()->eq('access', $query->createNamedParameter(self::ACCESS_PUBLIC)));
+		$query->execute();
+		return null;
+	}
+
+	/**
+	 * @param \OCA\DAV\CalDAV\Calendar $calendar
+	 * @return mixed
+	 */
+	public function getPublishStatus($calendar) {
+		$query = $this->db->getQueryBuilder();
+		$result = $query->select('publicuri')
+			->from('dav_shares')
+			->where($query->expr()->eq('resourceid', $query->createNamedParameter($calendar->getResourceId())))
+			->andWhere($query->expr()->eq('access', $query->createNamedParameter(self::ACCESS_PUBLIC)))
+			->execute();
+
+		$row = $result->fetch();
+		$result->closeCursor();
+		return $row ? reset($row) : false;
+	}
+
 	/**
 	 * @param int $resourceId
 	 * @param array $acl
@@ -1432,6 +1984,130 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		return $this->sharingBackend->applyShareAcl($resourceId, $acl);
 	}
 
+
+
+	/**
+	 * update properties table
+	 *
+	 * @param int $calendarId
+	 * @param string $objectUri
+	 * @param string $calendarData
+	 */
+	public function updateProperties($calendarId, $objectUri, $calendarData) {
+		$objectId = $this->getCalendarObjectId($calendarId, $objectUri);
+
+		try {
+			$vCalendar = $this->readCalendarData($calendarData);
+		} catch (\Exception $ex) {
+			return;
+		}
+
+		$this->purgeProperties($calendarId, $objectId);
+
+		$query = $this->db->getQueryBuilder();
+		$query->insert($this->dbObjectPropertiesTable)
+			->values(
+				[
+					'calendarid' => $query->createNamedParameter($calendarId),
+					'objectid' => $query->createNamedParameter($objectId),
+					'name' => $query->createParameter('name'),
+					'parameter' => $query->createParameter('parameter'),
+					'value' => $query->createParameter('value'),
+				]
+			);
+
+		$indexComponents = ['VEVENT', 'VJOURNAL', 'VTODO'];
+		foreach ($vCalendar->getComponents() as $component) {
+			if (!in_array($component->name, $indexComponents)) {
+				continue;
+			}
+
+			foreach ($component->children() as $property) {
+				if (in_array($property->name, self::$indexProperties)) {
+					$value = $property->getValue();
+					// is this a shitty db?
+					if (!$this->db->supports4ByteText()) {
+						$value = preg_replace('/[\x{10000}-\x{10FFFF}]/u', "\xEF\xBF\xBD", $value);
+					}
+					$value = mb_substr($value, 0, 254);
+
+					$query->setParameter('name', $property->name);
+					$query->setParameter('parameter', null);
+					$query->setParameter('value', $value);
+					$query->execute();
+				}
+
+				if (in_array($property->name, array_keys(self::$indexParameters))) {
+					$parameters = $property->parameters();
+					$indexedParametersForProperty = self::$indexParameters[$property->name];
+
+					foreach ($parameters as $key => $value) {
+						if (in_array($key, $indexedParametersForProperty)) {
+							// is this a shitty db?
+							if ($this->db->supports4ByteText()) {
+								$value = preg_replace('/[\x{10000}-\x{10FFFF}]/u', "\xEF\xBF\xBD", $value);
+							}
+							$value = mb_substr($value, 0, 254);
+
+							$query->setParameter('name', $property->name);
+							$query->setParameter('parameter', substr($key, 0, 254));
+							$query->setParameter('value', substr($value, 0, 254));
+							$query->execute();
+						}
+					}
+				}
+			}
+		}
+	}
+
+	/**
+	 * read VCalendar data into a VCalendar object
+	 *
+	 * @param string $objectData
+	 * @return VCalendar
+	 */
+	protected function readCalendarData($objectData) {
+		return Reader::read($objectData);
+	}
+
+	/**
+	 * delete all properties from a given calendar object
+	 *
+	 * @param int $calendarId
+	 * @param int $objectId
+	 */
+	protected function purgeProperties($calendarId, $objectId) {
+		$query = $this->db->getQueryBuilder();
+		$query->delete($this->dbObjectPropertiesTable)
+			->where($query->expr()->eq('objectid', $query->createNamedParameter($objectId)))
+			->andWhere($query->expr()->eq('calendarid', $query->createNamedParameter($calendarId)));
+		$query->execute();
+	}
+
+	/**
+	 * get ID from a given calendar object
+	 *
+	 * @param int $calendarId
+	 * @param string $uri
+	 * @return int
+	 */
+	protected function getCalendarObjectId($calendarId, $uri) {
+		$query = $this->db->getQueryBuilder();
+		$query->select('id')->from('calendarobjects')
+			->where($query->expr()->eq('uri', $query->createNamedParameter($uri)))
+			->andWhere($query->expr()->eq('calendarid', $query->createNamedParameter($calendarId)));
+
+		$result = $query->execute();
+		$objectIds = $result->fetch();
+		$result->closeCursor();
+
+		if (!isset($objectIds['id'])) {
+			throw new \InvalidArgumentException('Calendarobject does not exists: ' . $uri);
+		}
+
+		return (int)$objectIds['id'];
+	}
+
 	private function convertPrincipal($principalUri, $toV2) {
 		if ($this->principalBackend->getPrincipalPrefix() === 'principals') {
 			list(, $name) = URLUtil::splitPath($principalUri);
@@ -1442,4 +2118,19 @@ class CalDavBackend extends AbstractBackend implements SyncSupport, Subscription
 		}
 		return $principalUri;
 	}
+
+	private function addOwnerPrincipal(&$calendarInfo) {
+		$ownerPrincipalKey = '{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal';
+		$displaynameKey = '{' . \OCA\DAV\DAV\Sharing\Plugin::NS_NEXTCLOUD . '}owner-displayname';
+		if (isset($calendarInfo[$ownerPrincipalKey])) {
+			$uri = $calendarInfo[$ownerPrincipalKey];
+		} else {
+			$uri = $calendarInfo['principaluri'];
+		}
+
+		$principalInformation = $this->principalBackend->getPrincipalByPath($uri);
+		if (isset($principalInformation['{DAV:}displayname'])) {
+			$calendarInfo[$displaynameKey] = $principalInformation['{DAV:}displayname'];
+		}
+	}
 }
