@@ -18,6 +18,7 @@ OC.L10N.register(
     "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile stabilire una condivisione federata, forse la password non è corretta.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Richiesta della condivisione federata inviata, riceverai un invito. Controlla le tue notifiche.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossibile stabilire una condivisione federata, sembra che il server da federare sia troppo datato (Nextcloud  <= 9).",
+    "It is not allowed to send federated group shares from this server." : "Non è consentito inviare condivisioni di gruppo federate da questo server.",
     "Sharing %s failed, because this item is already shared with %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con %s",
     "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
     "File is already shared with %s" : "Il file è già condiviso con %s",
@@ -33,11 +34,14 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
     "Sharing" : "Condivisione",
     "Federated file sharing" : "Condivisione file federata",
+    "Provide federated file sharing across servers" : "Fornisce una condivisione di file federata tra server",
     "Federated Cloud Sharing" : "Condivisione cloud federata",
     "Open documentation" : "Apri la documentazione",
     "Adjust how people can share between servers." : "Regola come le persone possono condividere tra i server.",
     "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
     "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
+    "Allow users on this server to send shares to groups on other servers" : "Consenti agli utenti su questo server di inviare condivisioni a gruppi su altri server",
+    "Allow users on this server to receive group shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni di gruppo da altri server",
     "Search global and public address book for users" : "Cerca gli utenti nella rubrica globale e pubblica",
     "Allow users to publish their data to a global and public address book" : "Consenti agli utenti di pubblicare i propri dati in una rubrica globale e pubblica",
     "Federated Cloud" : "Cloud federata",
