@@ -1,17 +1,12 @@
 OC.L10N.register(
     "files_external",
     {
-    "Fetching request tokens failed. Verify that your app key and secret are correct." : "אחזור מחרוזת כניסה נכשל. יש לוודא שמפתח היישום והסוד נכונים.",
-    "Fetching access tokens failed. Verify that your app key and secret are correct." : "אחזור מחרוזת כניסה נכשל. יש לוודא שמפתח היישום והסוד נכונים.",
-    "Please provide a valid app key and secret." : "יש לספק מפתח יישום וסוד תקניים.",
-    "Step 1 failed. Exception: %s" : "שלב 1 נכשל. חריג: %s",
-    "Step 2 failed. Exception: %s" : "שלב 2 נכשל. חריג: %s",
-    "Dropbox App Configuration" : "הגדרות יישום דרופבוקס",
-    "Google Drive App Configuration" : "הגדרות יישום גוגל דרייב",
+    "External storages" : "התקני אחסון חיצוניים",
     "Personal" : "אישי",
     "System" : "מערכת",
     "Grant access" : "הענקת גישה",
     "Error configuring OAuth1" : "שגיאה בתצורת OAuth1",
+    "Please provide a valid app key and secret." : "יש לספק מפתח יישום וסוד תקניים.",
     "Error configuring OAuth2" : "שגיאה בתצורת OAuth2",
     "Generate keys" : "יצירת מפתחות",
     "Error generating key pair" : "שגיאה ביצירת זוג מפתחות",
@@ -19,13 +14,19 @@ OC.L10N.register(
     "(group)" : "(קבוצה)",
     "Compatibility with Mac NFD encoding (slow)" : "תואם של קידוד Mac NFD (איטי)",
     "Admin defined" : "הוגדר מנהל",
+    "Are you sure you want to delete this external storage?" : "למחוק את האחסון החיצוני הזה?",
+    "Delete storage?" : "למחוק אחסון?",
     "Saved" : "נשמר",
+    "Saving..." : "מתבצעת שמירה…",
     "Save" : "שמירה",
     "Empty response from the server" : "תגובה ריקה מהשרת",
+    "Couldn't access. Please log out and in again to activate this mount point" : "לא ניתן לגשת. נא לצאת ולהיכנס שוב כדי להפעיל את נקודת העגינה הזו",
+    "Couldn't get the information from the remote server: {code} {type}" : "לא ניתן לקבל את המידע מהשרת המרוחק: {code} {type}",
     "Couldn't get the list of external mount points: {type}" : "לא ניתן היה לקבל את רשימת נקודות העיגון החיצוניות: {type}",
     "There was an error with message: " : "התרחשה שגיאה עם הודעה: ",
     "External mount error" : "שגיאת עגינה חיצונית",
     "external-storage" : "אחסון חיצוני",
+    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "לא ניתן לקבל את רשימת נקודות העגינה לכונני רשת ב־Windows: תגובה ריקה מהשרת",
     "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "חלק מנקודות העיגון החיצוניות שהוגדרו אינן מחוברות. יש ללחוץ על השורה/ות האדומה/ות למידע נוסף",
     "Please enter the credentials for the {mount} mount" : "יש להזין את פרטי הגישה עבור התקן עגינה {mount}",
     "Username" : "שם משתמש",
@@ -33,6 +34,7 @@ OC.L10N.register(
     "Credentials saved" : "פרטי גישה נשמרו",
     "Credentials saving failed" : "שמירת פרטי גישה נכשלה",
     "Credentials required" : "נדרשים פרטי גישה",
+    "Storage with ID \"%d\" not found" : "לא נמצא התקן אחסון עם המזהה „%d”",
     "Invalid backend or authentication mechanism class" : "צד אחורי או סוג מנגנון אימות לא חוקי",
     "Invalid mount point" : "נקודת עגינה לא חוקית",
     "Objectstore forbidden" : "Objectstore חסום",
@@ -43,6 +45,7 @@ OC.L10N.register(
     "Unsatisfied authentication mechanism parameters" : "פרמטרים של מכניזם אימות אינם מספקים",
     "Insufficient data: %s" : "מידע לא מספק: %s",
     "%s" : "%s",
+    "Storage with ID \"%d\" is not user editable" : "למשתמשים אין אפשרות לערוך התקן אחסון עם מזהה „%d”",
     "Access key" : "מפתח כניסה",
     "Secret key" : "מפתח סודי",
     "Builtin" : "מובנה",
@@ -53,15 +56,22 @@ OC.L10N.register(
     "OAuth2" : "OAuth2",
     "Client ID" : "זיהוי לקוח",
     "Client secret" : "סוד לקוח",
-    "OpenStack" : "OpenStack",
+    "OpenStack v2" : "OpenStack v2",
     "Tenant name" : "שם דייר",
     "Identity endpoint URL" : "זהות נתיב נקודת קצה",
+    "OpenStack v3" : "OpenStack v3",
+    "Domain" : "שם תחום",
     "Rackspace" : "חץ אחורה",
     "API key" : "מפתח API",
+    "Global credentials" : "פרטי גישה גלובליים",
+    "Log-in credentials, save in database" : "פרטי כניסה, שמירה במסד הנתונים",
     "Username and password" : "שם משתמש וסיסמא",
     "Log-in credentials, save in session" : "אישורי התחברות, נשמרים במידע שיחה - סשן",
+    "User entered, store in database" : "הוכנס על ידי המשתמש, אחסון במסד הנתונים",
     "RSA public key" : "מפתח ציבורי RSA",
     "Public key" : "מפתח ציבורי",
+    "RSA private key" : "מפתח RSA פרט",
+    "Private key" : "מפתח פרט",
     "Amazon S3" : "אמזון S3",
     "Bucket" : "סל",
     "Hostname" : "שם מארח",
@@ -69,30 +79,29 @@ OC.L10N.register(
     "Region" : "אזור",
     "Enable SSL" : "הפעלת SSL",
     "Enable Path Style" : "אהפעלת סגנון נתיב",
+    "Legacy (v2) authentication" : "אימות מיושן (v2)",
     "WebDAV" : "WebDAV",
     "URL" : "נתיב אינטרנט",
     "Remote subfolder" : "תיקיית משנה רחוקה",
     "Secure https://" : "פרוטוקול מאובטח https://",
-    "Dropbox" : "דרופבוקס",
     "FTP" : "FTP",
     "Host" : "מארח",
     "Secure ftps://" : "פרוטוקול מאובטח ftps://",
-    "Google Drive" : "גוגל דרייב",
     "Local" : "מקומי",
     "Location" : "מיקום",
+    "Nextcloud" : "Nextcloud",
     "SFTP" : "SFTP",
     "Root" : "נתיב ראשי",
     "SFTP with secret key login" : "SFTP עם מפתח כניסה סודי",
     "SMB / CIFS" : "SMB / CIFS",
     "Share" : "שיתוף",
-    "Domain" : "שם תחום",
     "SMB / CIFS using OC login" : "SMB / CIFS בשימוש עם כניסת OC",
     "Username as share" : "שם משתמש כשיתוף",
     "OpenStack Object Storage" : "אחסון אובייקט OpenStack",
     "Service name" : "שם שירות",
     "Request timeout (seconds)" : "פסק זמן מבוקש (שניות)",
-    "No external storage configured" : "לא מוגדר אחסון חיצוני",
-    "You can add external storages in the personal settings" : "ניתן להוסיף אחסונים חיצוניים בהגדרות האישיות",
+    "External storage support" : "תמיכה באחסון חיצוני",
+    "No external storage configured or you don't have the permission to configure them" : "לא הוגדר התקן חיצוני או שאין לך הרשאות להגדיר כאלה",
     "Name" : "שם",
     "Storage type" : "סוג אחסון",
     "Scope" : "היקף",
@@ -102,17 +111,29 @@ OC.L10N.register(
     "Check for changes" : "בדיקה אחר שינויים",
     "Never" : "לעולם לא",
     "Once every direct access" : "פעם אחת כל כניסה ישירה",
+    "Read only" : "קריאה בלבד",
     "Folder name" : "שם התיקייה",
     "External storage" : "אחסון חיצוני",
     "Authentication" : "אימות",
     "Configuration" : "הגדרות",
     "Available for" : "זמין עבור",
+    "Click to recheck the configuration" : "יש ללחוץ כאן כדי לבדוק את ההגדרות מחדש",
     "Add storage" : "הוספת אחסון",
     "Advanced settings" : "הגדרות מתקדמות",
-    "Delete" : "מחיקה",
     "Allow users to mount external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני",
+    "Fetching request tokens failed. Verify that your app key and secret are correct." : "קבלת אסימוני בקשה נכשלה. נא לוודא שהמפתח והסוד של היישומון שלך נכונים.",
+    "Fetching access tokens failed. Verify that your app key and secret are correct." : "קבלת אסימוני גישה נכשלה. נא לוודא שהמפתח והסוד של היישומון שלך נכונים.",
+    "Step 1 failed. Exception: %s" : "שלב 1 נכשל: חריגה: %s",
+    "Step 2 failed. Exception: %s" : "שלב 2 נכשל. חריגה: %s",
+    "Dropbox App Configuration" : "הגדרות יישומון Dropbox",
+    "Google Drive App Configuration" : "הגדרות יישומון Google Drive",
+    "OpenStack" : "OpenStack",
+    "Dropbox" : "Dropbox",
+    "Google Drive" : "Google Drive",
+    "No external storage configured" : "לא מוגדר אחסון חיצוני",
+    "You can add external storages in the personal settings" : "ניתן להוסיף אחסונים חיצוניים בהגדרות האישיות",
+    "Delete" : "מחיקה",
     "Allow users to mount the following external storage" : "מאפשר למשתמשים לחבר אחסון חיצוני הבא",
-    "Storage with id \"%i\" not found" : "אחסון עם מספר זיהוי \"%i\" לא אותר",
-    "Storage with id \"%i\" is not user editable" : "האחסון עם זהות \"%i\" לא ניתן לעריכה"
+    "Are you sure you want to delete this external storage" : "למחוק את התקן האחסון החיצוני הזה"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
