@@ -94,8 +94,8 @@ var Files_Texteditor = {
 		clearTimeout(OCA.Files_Texteditor.saveMessageTimeout);
 
 		// Set the saving status
-		$('#editor_controls small.saving-message')
-			.text(t('files_texteditor', 'saving...'))
+		var $message = $('#editor_controls').find('small.saving-message');
+		$message.text(t('files_texteditor', 'saving...'))
 			.show();
 		// Send to server
 		OCA.Files_Texteditor.saveFile(
@@ -110,8 +110,7 @@ var Files_Texteditor = {
 				OCA.Files_Texteditor.file.mtime = data.mtime;
 				OCA.Files_Texteditor.file.size = data.size;
 
-				$('#editor_controls small.saving-message')
-					.text(t('files_texteditor', 'saved!'));
+				$message.text(t('files_texteditor', 'saved!'));
 				OCA.Files_Texteditor.saveMessageTimeout = setTimeout(function() {
 					$('small.saving-message').fadeOut(200);
 				}, 2000);
@@ -149,21 +148,20 @@ var Files_Texteditor = {
 			OCA.Files_Texteditor.saveFile(
 				window.aceEditor.getSession().getValue(),
 				OCA.Files_Texteditor.file,
-				function(data){
+				function() {
 					OC.Notification.showTemporary(t(
 						'files_texteditor',
 						'Saved'
 						)
-					)
+					);
 					// Remove the editor
 					OCA.Files_Texteditor.closeEditor();
 				},
-				function(message){
+				function() {
 					OC.Notification.showTemporary(t(
 						'files_texteditor',
 						'There was a problem saving your changes. Click to resume editing.'
-						)
-					);
+					));
 					$('#notification').data('reopeneditor', true).on(
 						'click',
 						OCA.Files_Texteditor._onReOpenTrigger
@@ -191,7 +189,7 @@ var Files_Texteditor = {
 		this.currentContext = context;
 		this.file.name = filename;
 		this.file.dir = context.dir;
-		this.fileInfoModel = context.fileList.getModelForFile(filename);
+		this.fileList = context.fileList;
 		this.loadEditor(
 			OCA.Files_Texteditor.$container,
 			OCA.Files_Texteditor.file
@@ -239,23 +237,28 @@ var Files_Texteditor = {
 		});
 	},
 
+	getSupportedMimetypes: function() {
+		return [
+			'text',
+			'application/cmd',
+			'application/javascript',
+			'application/json',
+			'application/xml',
+			'application/x-empty',
+			'application/x-msdos-program',
+			'application/x-php',
+			'application/x-pearl',
+			'application/x-text',
+			'application/yaml'
+		];
+	},
+
 	/**
 	 * Registers the file actions
 	 */
 	registerFileActions: function() {
-		var mimes = [
-				'text',
-				'application/javascript',
-				'application/json',
-				'application/xml',
-				'application/x-empty',
-				'application/x-php',
-				'application/x-pearl',
-				'application/x-text',
-				'application/yaml'
-			];
-
-		_self = this;
+		var mimes = this.getSupportedMimetypes(),
+			_self = this;
 
 		$.each(mimes, function(key, value) {
 			OCA.Files.fileActions.registerAction({
@@ -301,7 +304,7 @@ var Files_Texteditor = {
 				// Configure ace
 				_self.configureACE(file);
 				// Show the controls
-				_self.loadControlBar(file, _self.currentContext);
+				_self.loadControlBar(file);
 				window.aceEditor.getSession().on('change', _self.setupAutosave);
 				_self.bindVisibleActions();
 				window.aceEditor.focus();
@@ -315,6 +318,7 @@ var Files_Texteditor = {
 					var text = window.aceEditor.getSession().getValue();
 					_self.previewPluginOnChange(text, _self.preview);
 					window.aceEditor.resize();
+					_self.loadPreviewControlBar();
 				} else {
 					_self.previewPluginOnChange = null;
 				}
@@ -334,7 +338,7 @@ var Files_Texteditor = {
 	/**
 	 * Load the editor control bar
 	 */
-	loadControlBar: function(file, context) {
+	loadControlBar: function(file) {
 		var html =
 			'<small class="filename">'+escapeHTML(file.name)+'</small>'
 			+'<small class="unsaved-star" style="display: none">*</small>'
@@ -348,6 +352,54 @@ var Files_Texteditor = {
 
 	},
 
+	setPreviewMode: function(mode) {
+		var container = $('#app-content-texteditor');
+		var controlBar = $('#preview_editor_controls');
+		controlBar.find('button').removeClass('active');
+		controlBar.find('button[data-type="' + mode + '"]').addClass('active');
+		switch (mode) {
+			case 'mixed':
+				container.find('#editor_container').addClass('hasPreview');
+				container.find('#editor').show();
+				container.find('#preview_wrap').css('width', '50%');
+				break;
+			case 'text':
+				container.find('#editor_container').removeClass('hasPreview');
+				container.find('#editor').show();
+				container.find('#preview_wrap').css('width', '50%');
+				break;
+			case 'image':
+				container.find('#editor_container').addClass('hasPreview');
+				container.find('#editor').hide();
+				container.find('#preview_wrap').css('width', '100%');
+				break;
+		}
+	},
+
+	loadPreviewControlBar: function() {
+		var makeButton = function (type, tooltip, active) {
+			var button = $('<button/>');
+			button.tooltip({
+				title: tooltip,
+				container: 'body',
+				placement: 'bottom',
+				delay: {show: 500, hide: 0}
+			});
+			if (active) {
+				button.addClass('active');
+			}
+			button.click(this.setPreviewMode.bind(this, type));
+			button.attr('data-type', type);
+			return button.css('background-image', 'url("' + OC.imagePath('files_texteditor', type) + '")');
+		}.bind(this);
+
+		var controls = $('<span/>').attr('id', 'preview_editor_controls');
+		controls.append(makeButton('text', t('files_texteditor', 'Edit')));
+		controls.append(makeButton('mixed', t('files_texteditor', 'Mixed'), true));
+		controls.append(makeButton('image', t('files_texteditor', 'Preview')));
+		$('#editor_close').after(controls);
+	},
+
 	/**
 	 * Removes the control bar
 	 */
@@ -377,7 +429,7 @@ var Files_Texteditor = {
 		$('#editor_close').on('click', _.bind(this._onCloseTrigger, this));
 		$(window).resize(OCA.Files_Texteditor.setFilenameMaxLength);
 		if(!$('html').hasClass('ie8')) {
-			window.onpopstate = function (e) {
+			window.onpopstate = function () {
 				self._onCloseTrigger();
 			}
 		}
@@ -387,7 +439,12 @@ var Files_Texteditor = {
 	 * Configure the ACE editor
 	 */
 	configureACE: function(file) {
+		ace.require('ace/config').set(
+			'basePath',
+			OC.filePath('files_texteditor', 'js', 'core/vendor/ace-builds/src-noconflict')
+		);
 		window.aceEditor = ace.edit(this.editor);
+		aceEditor.getSession().setNewLineMode("windows");
 		aceEditor.setShowPrintMargin(false);
 		aceEditor.getSession().setUseWrapMode(true);
 		if (!file.writeable) { aceEditor.setReadOnly(true); }
@@ -402,7 +459,7 @@ var Files_Texteditor = {
 		// Set the theme
 		OC.addScript(
 			'files_texteditor',
-			'vendor/ace/src-noconflict/theme-clouds',
+			'core/vendor/ace-builds/src-noconflict/theme-clouds',
 			function () {
 				window.aceEditor.setTheme("ace/theme/clouds");
 			}
@@ -424,13 +481,12 @@ var Files_Texteditor = {
 		window.aceEditor.commands.removeCommand(window.aceEditor.commands.byName.transposeletters);
 	},
 
-	/**
-	 * Sets the syntax highlighting for the editor based on the file extension
-	 */
-	setEditorSyntaxMode: function(extension) {
+	getSyntaxMode: function(extension) {
 		// Loads the syntax mode files and tells the editor
-		var filetype = new Array();
+		var filetype = [];
 		// add file extensions like this: filetype["extension"] = "filetype":
+		filetype["bat"] = "batchfile";
+		filetype["cmd"] = "batchfile";
 		filetype["h"] = "c_cpp";
 		filetype["c"] = "c_cpp";
 		filetype["clj"] = "clojure";
@@ -463,7 +519,7 @@ var Files_Texteditor = {
 		filetype["mli"] = "ocaml";
 		filetype["pl"] = "perl";
 		filetype["php"] = "php";
-		filetype["powershell"] = "ps1";
+		filetype["ps1"] = "powershell";
 		filetype["py"] = "python";
 		filetype["rb"] = "ruby";
 		filetype["scad"] = "scad"; // seems to be something like 3d model files printed with e.g. reprap
@@ -478,15 +534,26 @@ var Files_Texteditor = {
 		if (filetype[extension] != null) {
 			// Then it must be in the array, so load the custom syntax mode
 			// Set the syntax mode
-			OC.addScript(
+			return OC.addScript(
 				'files_texteditor',
-				'vendor/ace/src-noconflict/mode-'+filetype[extension],
-				function () {
-					var SyntaxMode = ace.require("ace/mode/" + filetype[extension]).Mode;
-					window.aceEditor.getSession().setMode(new SyntaxMode());
-				}
-			);
+				'core/vendor/ace-builds/src-noconflict/mode-' + filetype[extension]
+			).then(function () {
+				return ace.require("ace/mode/" + filetype[extension]).Mode;
+			});
 		}
+
+		return $.when();
+	},
+
+	/**
+	 * Sets the syntax highlighting for the editor based on the file extension
+	 */
+	setEditorSyntaxMode: function(extension) {
+		this.getSyntaxMode(extension).then(function(SyntaxMode) {
+			if (SyntaxMode) {
+				window.aceEditor.getSession().setMode(new SyntaxMode());
+			}
+		});
 	},
 
 	/**
@@ -515,10 +582,9 @@ var Files_Texteditor = {
 	 */
 	saveFile: function(data, file, success, failure) {
 		// Send the post request
-		if(file.dir == '/') {
-			var path = file.dir + file.name;
-		} else {
-			var path = file.dir + '/' + file.name;
+		var path = file.dir + file.name;
+		if (file.dir !== '/') {
+			path = file.dir + '/' + file.name;
 		}
 		$.ajax({
 			type: 'PUT',
@@ -549,10 +615,11 @@ var Files_Texteditor = {
 		this.$container.html('').show();
 		this.unloadControlBar();
 		this.unBindVisibleActions();
-		if (this.fileInfoModel) {
-			this.fileInfoModel.set({
+		var fileInfoModel = this.fileList.getModelForFile(this.file.name);
+		if (fileInfoModel) {
+			fileInfoModel.set({
 				// temp dummy, until we can do a PROPFIND
-				etag: this.fileInfoModel.get('id') + this.file.mtime,
+				etag: fileInfoModel.get('id') + this.file.mtime,
 				mtime: this.file.mtime * 1000,
 				size: this.file.size
 			});
@@ -573,8 +640,8 @@ var Files_Texteditor = {
 	 * Configure the autosave timer
 	 */
 	setupAutosave: function() {
-		clearTimeout(this.saveTimer);
-		this.saveTimer = setTimeout(OCA.Files_Texteditor._onSaveTrigger, 3000);
+		clearTimeout(OCA.Files_Texteditor.saveTimer);
+		OCA.Files_Texteditor.saveTimer = setTimeout(OCA.Files_Texteditor._onSaveTrigger, 3000);
 	},
 
 	/**
@@ -617,7 +684,7 @@ Files_Texteditor.NewFileMenuPlugin = {
 		// register the new menu entry
 		menu.addMenuEntry({
 			id: 'file',
-			displayName: t('files_texteditor', 'Text file'),
+			displayName: t('files_texteditor', 'New text file'),
 			templateName: t('files_texteditor', 'New text file.txt'),
 			iconClass: 'icon-filetype-text',
 			fileType: 'file',
