@@ -4,9 +4,9 @@ OC.L10N.register(
     "Could not revert: %s" : "Невозможно откатить: %s",
     "Versions" : "Версии",
     "Failed to revert {file} to revision {timestamp}." : "Не удалось откатить {file} к ревизии {timestamp}.",
+    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
     "Restore" : "Откатить",
-    "No versions available" : "Нет доступных версий",
-    "More versions..." : "Ещё версии...",
-    "No other versions available" : "Других версий не доступно"
+    "No earlier versions available" : "Нет более ранних версий…",
+    "More versions …" : "Ещё версии…"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
