@@ -11,6 +11,8 @@ OC.L10N.register(
     "One or more entries are hidden by the log level filter" : "Uns o più voci sono nascoste dal filtro del livello di registrazione",
     "Everything is working fine" : "Tutto funziona correttamente",
     "Logging" : "Registrazione",
-    "Log Reader" : "Lettore dei log"
+    "Log Reader" : "Lettore dei log",
+    "A log reader for Nextcloud" : "Un lettore di log per Nextcloud",
+    "Log reader for Nextcloud" : "Lettore di log per Nextcloud"
 },
 "nplurals=2; plural=(n != 1);");
