@@ -1,5 +1,6 @@
 <?php
 	script('updatenotification', 'admin');
+	style('updatenotification', 'admin');
 
 	/** @var array $_ */
 	/** @var bool $isNewVersionAvailable */
@@ -14,15 +15,18 @@
 	$currentChannel = $_['currentChannel'];
 ?>
 <form id="oca_updatenotification_section" class="followupsection">
-
-	<?php if($_['outdatedPHP'] === true) { ?>
-		<p class="warning" style="margin-bottom: 15px;">
-			<?php p($l->t('You are running PHP %s. To allow you to upgrade to Nextcloud 11 and higher you need to run at least PHP 5.6. Once you upgraded your PHP version you will be able to receive update notifications for these newer versions.', [PHP_MAJOR_VERSION . '.' . PHP_MINOR_VERSION])); ?>
-		</p>
-	<?php } ?>
-
 	<?php if($isNewVersionAvailable === true) { ?>
 		<strong><?php p($l->t('A new version is available: %s', [$newVersionString])); ?></strong>
+
+		<?php if (!empty($_['versionIsEol'])) { ?>
+			<p class="eol">
+						<span class="warning">
+							<span class="icon icon-error"></span>
+							<?php p($l->t('The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible.')); ?>
+						</span>
+			</p>
+		<?php } ?>
+
 		<?php if ($_['updaterEnabled']) { ?>
 			<input type="button" id="oca_updatenotification_button" value="<?php p($l->t('Open updater')) ?>">
 		<?php } ?>
@@ -30,7 +34,7 @@
 			<a href="<?php p($_['downloadLink']); ?>" class="button<?php if ($_['updaterEnabled']) { p(' hidden'); } ?>"><?php p($l->t('Download now')) ?></a>
 		<?php } ?>
 	<?php } else { ?>
-		<strong><?php print_unescaped($l->t('Your version is up to date.')); ?></strong>
+		<?php p($l->t('Your version is up to date.')); ?>
 		<span class="icon-info svg" title="<?php p($l->t('Checked on %s', [$lastCheckedDate])) ?>"></span>
 	<?php } ?>
 
@@ -48,6 +52,7 @@
 	</p>
 	<p>
 		<em><?php p($l->t('You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel.')); ?></em>
+		<em><?php p($l->t('Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found.')); ?></em>
 	</p>
 
 
