@@ -35,6 +35,7 @@ OC.L10N.register(
     "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
     "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
     "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
+    "Waiting for cron to finish (checks again in 5 seconds) …" : "Warte auf das Beenden von Cron (neue Prüfung in 5 Sekunden)…",
     "Updating database schema" : "Das Datenbankschema wird aktualisiert",
     "Updated database" : "Datenbank aktualisiert",
     "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüft, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
@@ -67,11 +68,10 @@ OC.L10N.register(
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
     "Saving..." : "Speichere…",
     "Dismiss" : "Ausblenden",
-    "This action requires you to confirm your password" : "Dieser Vorgang benötigt eine Passwortbestätigung von Dir",
     "Authentication required" : "Legitimierung benötigt",
-    "Password" : "Passwort",
-    "Cancel" : "Abbrechen",
+    "This action requires you to confirm your password" : "Dieser Vorgang benötigt eine Passwortbestätigung von Dir",
     "Confirm" : "Bestätigen",
+    "Password" : "Passwort",
     "Failed to authenticate, try again" : "Legitimierung fehlgeschlagen, noch einmal versuchen",
     "seconds ago" : "Gerade eben",
     "Logging in …" : "Melde an…",
@@ -84,6 +84,7 @@ OC.L10N.register(
     "No" : "Nein",
     "Yes" : "Ja",
     "No files in here" : "Keine Dateien vorhanden",
+    "No more subfolders in here" : "Keine weiteren Unterordner vorhanden",
     "Choose" : "Auswählen",
     "Copy" : "Kopieren",
     "Move" : "Verschieben",
@@ -97,6 +98,7 @@ OC.L10N.register(
     "Already existing files" : "Bereits existierende Dateien",
     "Which files do you want to keep?" : "Welche Dateien sollen erhalten bleiben?",
     "If you select both versions, the copied file will have a number added to its name." : "Falls beide Versionen gewählt werden, wird bei der kopierten Datei eine Zahl am Ende des Dateinamens hinzugefügt.",
+    "Cancel" : "Abbrechen",
     "Continue" : "Fortsetzen",
     "(all selected)" : "(Alle ausgewählt)",
     "({count} selected)" : "({count} ausgewählt)",
@@ -104,6 +106,8 @@ OC.L10N.register(
     "Pending" : "Ausstehend",
     "Copy to {folder}" : "Kopieren nach {folder}",
     "Move to {folder}" : "Verschieben nach {folder}",
+    "New in" : "Neu in",
+    "View changelog" : "Liste der Veränderungen anschauen",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Passables Passwort",
@@ -111,31 +115,47 @@ OC.L10N.register(
     "Strong password" : "Starkes Passwort",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Dein Webserver ist noch nicht hinreichend für Datei-Synchronisation konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Dein Web-Server ist nicht richtig eingerichtet um \"{url}\" aufzulösen. Weitere Informationen findest du in der <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation</a>.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP scheint zur Abfrage von Systemumgebungsvariablen nicht richtig eingerichtet zu sein. Der Test mit getenv(\"PATH\") liefert nur eine leere Antwort zurück.",
+    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Bitte die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Installationsdokumentation ↗</a> auf Hinweise zur PHP-Konfiguration durchlesen, sowie die PHP-Konfiguration Deines Servers überprüfen, insbesondere dann, wenn PHP-FPM eingesetzt wird.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Die schreibgeschützte Konfiguration wurde aktiviert. Dies verhindert das Setzen einiger Einstellungen über die Web-Schnittstelle. Weiterhin muss bei jedem Update der Schreibzugriff auf die Datei händisch aktiviert werden.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Deine Datenbank läuft nicht mit der \"READ COMMITED\" Transaktionsisolationsstufe. Dies kann Probleme hervorrufen, wenn mehrere Aktionen parallel ausgeführt werden.",
+    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Das PHP-Modul 'fileinfo' fehlt. Es empfiehlt sich dringend, das Modul zu aktivieren, um bestmögliche Ergebnisse bei der MIME-Datei-Typ-Erkennung zu erhalten. ",
+    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} ist in einer älteren Version als {version} installiert. Aus Stabilitäts- und Performancegründen empfehlen wir eine Aktualisierung auf eine neuere {name}-Version",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "Transaktionales Sperren ist deaktiviert, was zu Problemen mit Laufzeitbedingungen führen kann. 'filelocking.enabled' in der config.php aktivieren, um diese Probleme zu vermeiden. Weitere Informationen findest du in unserer <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation ↗</a>.",
+    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "Wenn sich Deine Installation nicht im Wurzelverzeichnis der Domain befindet und Cron des Systems genutzt wird, kann es zu Fehlern bei der URL-Generierung kommen. Um dies zu verhindern, setze bitte die „overwrite.cli.url“-Option in Deiner config.php auf das Web-Wurzelverzeichnis Deiner Installation (Vorschlag: \"{suggestedOverwriteCliURL}\")",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Die Ausführung des Cron-Jobs über die Kommandozeile war nicht möglich. Die folgenden technischen Fehler sind dabei aufgetreten: ",
+    "Last background job execution ran {relativeTime}. Something seems wrong." : "Letzte Cron-Job-Ausführung: {relativeTime}. Möglicherweise liegt ein Fehler vor.",
+    "Check the background job settings" : "Überprüfe Cron-Job Einstellungen",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Dieser Server hat keine funktionierende Internetverbindung: Mehrere Ziele konnten nicht erreicht werden. Dies bedeutet, dass einige Funktionen, wie das Einhängen exernen Speichers, Benachrichtigungen über Updates oder die Installation von Drittanbieter-Apps nicht funktionieren. Der Zugriff auf entfernte Dateien und das Senden von E-Mail-Benachrichtigungen wird wahrscheinlich ebenfalls nicht funktionieren. Um alle Funktionen nutzen zu können, stelle eine Internet-Verbindung für diesen Server her.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Es wurde kein PHP-Memory-Cache konfiguriert. Zur Erhöhung der Leistungsfähigkeit kann ein Memory-Cache konfiguriert werden. Weitere Informationen finden Sie in der <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation</a>.",
     "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP hat keine Leserechte auf /dev/urandom wovon aus Sicherheitsgründen höchst abzuraten ist. Weitere Informationen sind in der <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation</a> zu finden.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du verwendest derzeit PHP {version}. Upgrade deine PHP-Version, um die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">Geschwindigkeits- und Sicherheitsupdates zu nutzen, welche von der PHP-Gruppe bereitgestellt werden</a>, sobald diese Deine Distribution unterstützt.",
-    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Die verwendest PHP 5.6. Die aktuelle Version von Nextcloud ist die letzte Version, die PHP 5.6 unterstützt. Es empfiehlt sich die PHP-Version auf 7.0 oder höher zu aktualisieren, um in der Lage zu sein, auf Nextcloud 14 zu aktualisieren.",
+    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "Du verwendest PHP 5.6. Die aktuelle Version von Nextcloud ist die letzte Version, die PHP 5.6 unterstützt. Es empfiehlt sich die PHP-Version auf 7.0 oder höher zu aktualisieren, um in der Lage zu sein, auf Nextcloud 14 zu aktualisieren.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Die Reverse-Proxy-Header-Konfiguration ist fehlerhaft oder Sie greifen auf Nextcloud über einen vertrauenswürdigen Proxy zu. Ist dies nicht der Fall, dann besteht ein Sicherheitsproblem, das einem Angreifer erlaubt die IP-Adresse, die für Nextcloud sichtbar ist, auszuspähen. Weitere Informationen hierzu finde sich in der <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation</a>.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ist als verteilter Cache konfiguriert, aber das falsche PHP-Modul \"memcache\" ist installiert. \\OC\\Memcache\\Memcached unterstützt nur \"memcached\" jedoch nicht \"memcache\". Im <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki nach beiden Modulen suchen</a>.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Einige Dateien haben die Integritätsprüfung nicht bestanden. Weiterführende Informationen befinden sich in unserer <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste der ungültigen Dateien…</a> / <a href=\"{rescanEndpoint}\">Erneut analysieren…</a>)",
+    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "Das PHP-OPcache-Modul ist nicht geladen. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Für eine bessere Leistung empfiehlt es sich</a> das Modul in Deiner PHP-Installation zu laden.",
     "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "Der PHP-OPcache ist nicht richtig konfiguriert. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Für eine bessere Leistung empfiehlt es sich</a> folgende Einstellungen in der <code>php.ini</code> vorzunehmen:",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Die PHP-Funktion \"set_time_limit\" ist nicht verfügbar. Dies kann in angehaltenen Scripten oder einer fehlerhaften Installation resultieren. Es wird dringend empfohlen, diese Funktion zu aktivieren.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Dein PHP unterstützt Freetype nicht. Dies wird defekte Profilbilder und eine defekte Anzeige der Einstellungen verursachen.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Fehlender Index \"{indexName}\" in der Tabelle \"{tableName}\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In der Datenbank fehlen einige Indizes. Auf Grund der Tatsache, dass das hinzufügen von Indizes in großen Tabellen einige Zeit in Anspruch nehmen wird, wurden diese nicht automatisch erzeugt. Durch das Ausführen von \"occ db:add-missing-indices\" können die fehlenden Indizes manuell hinzugefügt werden, während die Instanz weiter läuft. Nachdem die Indizes hinzugefügt wurden, sind Anfragen auf die Tabellen normalerweise schneller.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite wird als Datenbank verwendet. Bei größeren Installationen wird empfohlen, auf ein anderes Datenbank-Backend zu wechseln.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Dies wird insbesondere bei der Benutzung des Desktop-Clients zur Synchronisierung empfohlen.",
+    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "Um zu einer anderen Datenbank zu migrieren, benutze bitte die Kommandozeile: 'occ db:convert-type', oder in die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Dokumentation ↗</a> schauen.",
+    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "Die Verwendung des eingebauten PHP-Mailers wird nicht länger unterstützt. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Bitte aktualisiere die E-Mail-Server-Einstellungen ↗<a/>.",
+    "The PHP memory limit is below the recommended value of 512MB." : "Die PHP-Speichergrenze liegt unterhalb des empfohlenen Wertes von 512MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Einige App-Ordner haben einen anderen Besitzer als der Benutzer des Webservers. Dies kann der Fall sein, wenn Apps manuell installiert wurden. Prüfe die Berechtigungen der folgenden App-Ordner:",
     "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, deinen Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass du es aus dem Dokument-Root-Verzeichnis des Webservers bewegst.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Der „{header}“-HTTP-Header ist nicht so konfiguriert, dass er „{expected}“ entspricht. Dies ist ein potentielles Sicherheitsrisiko und es wird empfohlen, diese Einstellung zu ändern.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Der „{header}“-HTTP-Header ist nicht so konfiguriert, dass er „{expected}“ entspricht. Einige Funktionen funktionieren möglicherweise nicht richtig. Daher wird empfohlen, diese Einstellung zu ändern.",
-    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Für mehr Sicherheit wird das Aktivieren von HSTS empfohlen, wie es in den <a href=\"{docUrl}\" rel=\"noreferrer noopener\">Sicherheitshinweisen</a> erläutert ist.",
-    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : "Der Zugriff auf diese Site erfolgt über HTTP. Es wird dringend geraten, Ihren Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in den <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\" or \"{val4}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "Der \"{header}\" HTTP-Header ist nicht gesetzt auf \"{val1}\", \"{val2}\", \"{val3}\" oder \"{val4}\". Dadurch können Verweis-Informationen preisgegeben werden. Siehe die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C-Empfehlung</a>.",
+    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Für mehr Sicherheit wird das Aktivieren von HSTS empfohlen, wie es in den <a href=\"{docUrl}\" rel=\"noreferrer noopener\">Sicherheitshinweisen</a> erläutert ist.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "Der Zugriff auf diese Site erfolgt über HTTP. Es wird dringend geraten, Ihren Server so zu konfigurieren, dass stattdessen nur HTTPS akzeptiert wird, wie es in den <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
     "Shared" : "Geteilt",
     "Shared with" : "Geteilt mit",
     "Shared by" : "Geteilt von",
-    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
-    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
-    "Set expiration date" : "Setze ein Ablaufdatum",
-    "Expiration" : "Ablaufdatum",
-    "Expiration date" : "Ablaufdatum",
     "Choose a password for the public link" : "Wähle ein Passwort für den öffentlichen Link",
     "Choose a password for the public link or press the \"Enter\" key" : "Wähle ein Passwort für die öffentliche Freigabe oder drücke \"Eingabe\"",
     "Copied!" : "Kopiert!",
@@ -144,7 +164,7 @@ OC.L10N.register(
     "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
     "Resharing is not allowed" : "Das Weiterverteilen ist nicht erlaubt",
     "Share to {name}" : "Mit {name} teilen",
-    "Share link" : "Link teilen",
+    "Copy URL" : "URL kopieren",
     "Link" : "Link",
     "Password protect" : "Passwortschutz",
     "Allow editing" : "Bearbeitung erlauben",
@@ -153,13 +173,23 @@ OC.L10N.register(
     "Allow upload and editing" : "Hochladen und Bearbeiten erlauben",
     "Read only" : "Schreibgeschützt",
     "File drop (upload only)" : "Dateien ablegen (nur Hochladen)",
+    "Set expiration date" : "Setze ein Ablaufdatum",
+    "Expiration" : "Ablaufdatum",
+    "Expiration date" : "Ablaufdatum",
+    "Note to recipient" : "Notiz an Empfänger",
+    "Share link" : "Link teilen",
+    "Enable" : "Aktivieren",
     "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Dir und der Gruppe {group} geteilt",
+    "Shared with you and {circle} by {owner}" : "Von {owner} mit Dir und {circle} geteilt",
+    "Shared with you and the conversation {conversation} by {owner}" : "Von {owner} mit Ihnen und der Unterhaltung {conversation} geteilt",
     "Shared with you by {owner}" : "{owner} hat dies mit Dir geteilt",
     "Choose a password for the mail share" : "Wähle ein Passwort für das Teilen via E-Mail",
     "{{shareInitiatorDisplayName}} shared via link" : "{{shareInitiatorDisplayName}} mittels Link geteilt",
     "group" : "Gruppe",
     "remote" : "Entfernte Freigabe",
+    "remote group" : "Externe Gruppe",
     "email" : "E-Mail",
+    "conversation" : "Unterhaltung",
     "shared by {sharer}" : "Geteilt von {sharer}",
     "Unshare" : "Freigabe aufheben",
     "Can reshare" : "kann weiterteilen",
@@ -167,6 +197,7 @@ OC.L10N.register(
     "Can create" : "kann erstellen",
     "Can change" : "kann ändern",
     "Can delete" : "kann löschen",
+    "Password protect by Talk" : "Passwortgeschützt von Talk",
     "Access control" : "Zugriffskontrolle",
     "Could not unshare" : "Freigabe konnte nicht aufgehoben werden",
     "Error while sharing" : "Fehler beim Teilen",
@@ -178,9 +209,11 @@ OC.L10N.register(
     "An error occurred (\"{message}\"). Please try again" : "Benötigt keine Übersetzung. Für iOS wird nur die formelle Übersetzung verwendet (de_DE). ",
     "An error occurred. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuche es noch einmal",
     "{sharee} (group)" : "{sharee} (Gruppe)",
-    "{sharee} (remote)" : "{sharee} (entfernt)",
+    "{sharee} (remote)" : "{sharee} (remote)",
+    "{sharee} (remote group)" : "{sharee} (externe Gruppe)",
     "{sharee} (email)" : "{sharee} (E-Mail)",
     "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
+    "{sharee} (conversation)" : "{sharee} (conversation)",
     "Share" : "Teilen",
     "Name or email address..." : "Name oder E-Mail-Adresse…",
     "Name or federated cloud ID..." : "Name oder Federated-Cloud-ID…",
@@ -194,8 +227,8 @@ OC.L10N.register(
     "({scope})" : "({scope})",
     "Delete" : "Löschen",
     "Rename" : "Umbenennen",
-    "Collaborative tags" : "Zusammenarbeits-Tags",
-    "No tags found" : "Keine Tags gefunden",
+    "Collaborative tags" : "Gemeinschaftliche Schlagworte",
+    "No tags found" : "Keine Schlagworte gefunden",
     "unknown text" : "Unbekannter Text",
     "Hello world!" : "Hallo Welt!",
     "sunny" : "sonnig",
@@ -263,6 +296,8 @@ OC.L10N.register(
     "Need help?" : "Hilfe nötig?",
     "See the documentation" : "Schau in die Dokumentation",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Diese Anwendung benötigt JavaScript zum ordnungsgemäßen Betrieb. Bitte {linkstart}aktiviere JavaScript{linkend} und lade die Seite neu.",
+    "Skip to main content" : "Zum Hauptinhalt springen",
+    "Skip to navigation of app" : "Zum Navigationsbereich der App springen",
     "More apps" : "Weitere Apps",
     "More apps menu" : "Weitere Apps-Menü",
     "Search" : "Suche",
@@ -278,6 +313,7 @@ OC.L10N.register(
     "Username or email" : "Benutzername oder E-Mail",
     "Log in" : "Anmelden",
     "Wrong password." : "Falsches Passwort.",
+    "User disabled" : "Nutzer deaktiviert",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von Deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
     "Forgot password?" : "Passwort vergessen?",
     "Back to login" : "Zur Anmeldung wechseln",
@@ -291,8 +327,11 @@ OC.L10N.register(
     "Redirecting …" : "Weiterleiten…",
     "New password" : "Neues Passwort",
     "New Password" : "Neues Passwort",
+    "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
+    "The password is wrong. Try again." : "Das Passwort ist falsch. Bitte versuche es erneut.",
     "Two-factor authentication" : "Zwei-Faktor Authentifizierung",
     "Enhanced security is enabled for your account. Please authenticate using a second factor." : "Die erweiterte Sicherheit wurde für Dein Konto aktiviert. Bitte authentifiziere Dich mit einem zweiten Faktor. ",
+    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Es konnte nicht eine Deiner Zwei-Faktor-Authentifizierungsmethoden geladen werden. Kontaktiere den Administrator.",
     "Cancel log in" : "Anmeldung abbrechen",
     "Use backup code" : "Backup-Code benutzen",
     "Error while validating your second factor" : "Fehler beim Bestätigen des zweiten Sicherheitsfaktors",
@@ -335,6 +374,8 @@ OC.L10N.register(
     "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Für mehr Sicherheit wird das Aktivieren von HSTS empfohlen, wie es in unseren <a href=\"{docUrl}\" rel=\"noreferrer\">Sicherheitshinweisen</a> erläutert ist.",
     "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du greifst auf diese Site über HTTP zu. Wir raten dringend dazu, deinen Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in unseren <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
     "Shared with {recipients}" : "Geteilt mit {recipients}",
+    "Error setting expiration date" : "Fehler beim Setzen des Ablaufdatums",
+    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
     "Share with other people by entering a user or group, a federated cloud ID or an email address." : "Teile mit Anderen, indem Du einen Benutzer, eine Gruppe, eine Federated-Cloud-ID oder eine E-Mail-Adressen eingibst.",
     "Share with other people by entering a user or group or a federated cloud ID." : "Teile mit Anderen, indem Du einen Benutzer, eine Gruppe, oder eine Federated-Cloud-ID eingibst.",
     "Share with other people by entering a user or group or an email address." : "Teile mit Anderen, indem Du einen Benutzer, eine Gruppe, oder eine E-Mail-Adresse eingibst.",
@@ -353,6 +394,8 @@ OC.L10N.register(
     "Add \"%s\" as trusted domain" : "„%s“ als vertrauenswürdige Domain hinzufügen",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schaue bitte in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation</a>.",
     "Your PHP does not have freetype support. This will result in broken profile pictures and settings interface." : "Dein PHP unterstützt Freetype nicht. Dies wird defekte Profilbilder und eine defekte Anzeige der Einstellungen verursachen.",
+    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Für mehr Sicherheit wird das Aktivieren von HSTS empfohlen, wie es in den <a href=\"{docUrl}\" rel=\"noreferrer noopener\">Sicherheitshinweisen</a> erläutert ist.",
+    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips</a>." : "Der Zugriff auf diese Site erfolgt über HTTP. Es wird dringend geraten, Ihren Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in den <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
     "Back to log in" : "Zur Anmeldung wechseln",
     "Depending on your configuration, this button could also work to trust the domain:" : "Abhängig von Deiner Konfiguration kann diese Schaltfläche verwandt werden, um die Domain als vertrauenswürdig einzustufen:"
 },
