@@ -4,7 +4,7 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "\"config\"ディレクトリに書き込めません！",
     "This can usually be fixed by giving the webserver write access to the config directory" : "多くの場合、これはWebサーバーにconfigディレクトリへの書き込み権限を与えることで解決できます。",
     "See %s" : "%s を閲覧",
-    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "多くの場合、これは %s Webサーバーにconfigディレクトリ %s への書き込み権限を与えることで解決できます。",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "多くの場合、Webサーバーの configディレクトリ に書き込み権限を与えることで直ります。%s を見てください",
     "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "アプリ %1$s のファイルが正しく置き換えられませんでした。サーバーと互換性のあるバージョンであることを確認してください。",
     "Sample configuration detected" : "サンプル設定が見つかりました。",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
@@ -12,6 +12,10 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s と %2$s、%3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s と %2$s、%3$s、%4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s と %2$s、%3$s、%4$s、%5$s",
+    "Education Edition" : "Education Edition",
+    "Enterprise bundle" : "エンタープライズ バンドル",
+    "Groupware bundle" : "グループウェア バンドル",
+    "Social sharing bundle" : "SNS バンドル",
     "PHP %s or higher is required." : "PHP %s 以上が必要です。",
     "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
     "%sbit or higher PHP required." : "%sbit 以上の新しいバージョンのPHPが必要です。",
@@ -23,43 +27,67 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
     "Server version %s or higher is required." : "サーバーの %s よりも高いバージョンが必要です。",
     "Server version %s or lower is required." : "サーバーの %s よりも低いバージョンが必要です。",
+    "Logged in user must be an admin" : "ログインユーザーは管理者である必要があります",
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
     "Avatar image is not square" : "アバター画像が正方形ではありません",
     "today" : "今日",
-    "yesterday" : "1日前",
+    "tomorrow" : "明日",
+    "yesterday" : "昨日",
+    "_in %n day_::_in %n days_" : ["%n 日"],
     "_%n day ago_::_%n days ago_" : ["%n 日前"],
-    "last month" : "1ヶ月前",
-    "_%n month ago_::_%n months ago_" : ["%nヶ月前"],
-    "last year" : "1年前",
+    "next month" : "来月",
+    "last month" : "先月",
+    "_in %n month_::_in %n months_" : ["%n ヶ月"],
+    "_%n month ago_::_%n months ago_" : ["%n ヶ月前"],
+    "next year" : "来年",
+    "last year" : "去年",
+    "_in %n year_::_in %n years_" : ["%n 年"],
     "_%n year ago_::_%n years ago_" : ["%n 年前"],
+    "_in %n hour_::_in %n hours_" : ["%n 時間"],
     "_%n hour ago_::_%n hours ago_" : ["%n 時間前"],
+    "_in %n minute_::_in %n minutes_" : ["%n 分"],
     "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
+    "in a few seconds" : "数秒",
     "seconds ago" : "数秒前",
-    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "id: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
     "File name is a reserved word" : "ファイル名が予約された単語です",
     "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
     "File name is too long" : "ファイル名が長すぎます",
     "Dot files are not allowed" : "ドットファイルは許可されていません",
     "Empty filename is not allowed" : "空のファイル名は許可されていません",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Server settings" : "サーバー設定",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
+    "__language_name__" : "Japanese (日本語)",
+    "This is an automatically sent email, please do not reply." : "これは自動的に生成されたメールです。返信しないでください。",
+    "Help" : "ヘルプ",
+    "Apps" : "アプリ",
+    "Settings" : "設定",
+    "Log out" : "ログアウト",
+    "Users" : "ユーザー",
+    "Unknown user" : "不明なユーザー",
+    "Create" : "作成",
+    "Change" : "変更",
+    "Delete" : "削除",
+    "Share" : "共有",
+    "Overview" : "概要",
+    "Basic settings" : "基本設定",
     "Sharing" : "共有",
-    "Encryption" : "暗号化",
+    "Security" : "セキュリティ",
     "Additional settings" : "追加設定",
-    "Tips & tricks" : "ヒントとコツ",
+    "Personal info" : "個人情報",
+    "Unlimited" : "無制限",
+    "Verifying" : "検証中",
+    "Verifying …" : "検証中",
+    "Verify" : "検証",
     "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
     "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
     "%s enter the database name." : "%s のデータベース名を入力してください。",
     "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
     "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
-    "Oracle username and/or password not valid" : "Oracleのユーザー名もしくはパスワードは有効ではありません",
-    "DB Error: \"%s\"" : "DBエラー: \"%s\"",
-    "Offending command was: \"%s\"" : "違反コマンド: \"%s\"",
-    "You need to enter either an existing account or the administrator." : "既存のアカウントもしくは管理者のどちらかを入力する必要があります。",
-    "Offending command was: \"%s\", name: %s, password: %s" : "違反コマンド: \"%s\"、名前: %s、パスワード: %s",
-    "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名もしくはパスワードは有効ではありません",
+    "Oracle username and/or password not valid" : "Oracleのユーザー名またはパスワードが有効ではありません",
+    "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
+    "You need to enter details of an existing account." : "既存のアカウントの詳細を入力してください。",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
@@ -68,28 +96,23 @@ OC.L10N.register(
     "Set an admin password." : "管理者のパスワードを設定",
     "Can't create or write into the data directory %s" : "%s データディレクトリに作成、書き込みができません",
     "Invalid Federated Cloud ID" : "無効な統合されたクラウドID",
-    "%s shared »%s« with you" : "%sが あなたと »%s«を共有しました",
-    "%s via %s" : "%s に %s から",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "%s を共有できませんでした。%i タイプからの共有は許可されていません。",
     "Sharing %s failed, because the file does not exist" : "%s を共有できませんでした。そのファイルは存在しません。",
     "You are not allowed to share %s" : "%s を共有することを許可されていません。",
     "Sharing %s failed, because you can not share with yourself" : "%s を共有できませんでした。自分自身に共有することはできません。",
     "Sharing %s failed, because the user %s does not exist" : "%s を共有できませんでした。ユーザー %s が存在しません。",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s を共有できませんでした。ユーザー %s はどのグループにも属していません。%s は、??のメンバーです。",
+    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "%s を共有できませんでした。ユーザー %s はどのグループにも属していません。%s は、次のグループのメンバーです",
     "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
     "Sharing %s failed, because this item is already shared with user %s" : "%s を共有できませんでした。このアイテムは、ユーザー %s によりすでに共有されています。",
     "Sharing %s failed, because the group %s does not exist" : "%s を共有できませんでした。グループ %s は存在しません。",
     "Sharing %s failed, because %s is not a member of the group %s" : "%s を共有できませんでした。%s は、グループ %s のメンバーではありません。",
     "You need to provide a password to create a public link, only protected links are allowed" : "公開用リンクの作成にはパスワードの設定が必要です",
     "Sharing %s failed, because sharing with links is not allowed" : "%s を共有できませんでした。リンクでの共有は許可されていません。",
-    "Not allowed to create a federated share with the same user" : "同じユーザーでフェデレーション共有を作成することは出来ません",
+    "Not allowed to create a federated share with the same user" : "同じユーザーでフェデレーション共有は作成できません。",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないようです。",
     "Share type %s is not valid for %s" : "%s の共有方法は、%s には適用できません。",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%s を共有できませんでした。%s に許可されている権限を越えています。",
-    "Setting permissions for %s failed, because the item was not found" : "%s を共有できませんでした。アイテムが存在しません。",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "有効期限を設定できません。共有開始から %s 以降に有効期限を設定することはできません。",
     "Cannot set expiration date. Expiration date is in the past" : "有効期限を設定できません。有効期限が過去を示しています。",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "有効期限を解除できません。共有するには有効期限を設定する必要があります。",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
     "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
     "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
@@ -98,11 +121,17 @@ OC.L10N.register(
     "Sharing %s failed, because resharing is not allowed" : "%s を共有できませんでした。再共有は許可されていません。",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s の共有に失敗しました。%s のバックエンド共有に必要なソースが見つかりませんでした。",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s の共有に失敗しました。ファイルキャッシュにファイルがありませんでした。",
-    "Cannot increase permissions of %s" : "%s　の権限を強化できません",
-    "Files can't be shared with delete permissions" : "削除権限つきでファイルを共有できません。",
-    "Files can't be shared with create permissions" : "作成権限つきでファイルを共有できません。",
+    "Open »%s«" : "»%s«を開く",
+    "Can’t increase permissions of %s" : "%s　の権限を追加できません",
+    "Files can’t be shared with delete permissions" : "削除権限つきでファイルを共有できません。",
+    "Files can’t be shared with create permissions" : "作成権限つきでファイルを共有できません。",
     "Expiration date is in the past" : "有効期限が切れています",
-    "Cannot set expiration date more than %s days in the future" : "有効期限を%s日以降に設定できません。",
+    "Can’t set expiration date more than %s days in the future" : "有効期限を%s日以降に設定できません。",
+    "%s shared »%s« with you" : "%sが あなたと »%s«を共有しました",
+    "%s shared »%s« with you." : "%sが あなたと »%s«を共有しました",
+    "Click the button below to open it." : "開くには下のボタンをクリック",
+    "%s via %s" : "%s に %s から",
+    "The requested share does not exist anymore" : "この共有はもう存在しません。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
     "Sunday" : "日曜日",
     "Monday" : "月曜日",
@@ -149,22 +178,15 @@ OC.L10N.register(
     "Oct." : "10月",
     "Nov." : "11月",
     "Dec." : "12月",
-    "Apps" : "アプリ",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列は、次のものです： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\"",
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
+    "Username must not consist of dots only" : "ユーザー名は、ドットのみではつけられません",
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
     "The username is already being used" : "ユーザー名はすでに使われています",
-    "Login canceled by app" : "アプリによりログインが中止されました",
+    "Could not create user" : "ユーザーを作成できませんでした",
     "User disabled" : "ユーザーは無効です",
-    "Help" : "ヘルプ",
-    "Personal" : "個人",
-    "Users" : "ユーザー",
-    "Admin" : "管理",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
-    "No app name specified" : "アプリ名が未指定",
-    "App '%s' could not be installed!" : "'%s' アプリをインストールできませんでした。",
+    "Login canceled by app" : "アプリによりログインが中止されました",
     "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
     "a safe home for all your data" : "あなたの全データの安全な家",
     "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
@@ -172,14 +194,13 @@ OC.L10N.register(
     "Application is not enabled" : "アプリケーションは無効です",
     "Authentication error" : "認証エラー",
     "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
-    "Unknown user" : "不明なユーザー",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "データベースドライバー (sqlite, mysql, postgresql) がインストールされていません。",
     "Cannot write into \"config\" directory" : "\"config\" ディレクトリに書き込みができません",
     "Cannot write into \"apps\" directory" : "\"apps\" ディレクトリに書き込みができません",
-    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "多くの場合、これは %s Webサーバーにappsディレクトリ %s への書き込み権限を与えるか、設定ファイルでアプリストアを無効化することで解決できます。",
-    "Cannot create \"data\" directory (%s)" : "\"data\" ディレクトリ (%s) を作成できません",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "通常、<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "多くの場合、パーミッションは %s Webサーバーにルートディレクトリ %s への書き込み権限を与えることで解決できます。",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "多くの場合、これは Webサーバーにappsディレクトリへの書き込み権限を与えるか、設定ファイルでアプリストアを無効化することで直ります。%s を見てください。",
+    "Cannot create \"data\" directory" : "\"data\" ディレクトリを作成できません",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "多くの場合、Webサーバーのルートディレクトリに書き込み権限を与えることで直ります。%s を見てください。",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Webサーバーのルートディレクトリに書き込み権限パーミッションが必要です。%s を見てください。",
     "Setting locale to %s failed" : "ロケールを %s に設定できませんでした",
     "Please install one of these locales on your system and restart your webserver." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
     "Please ask your server administrator to install the module." : "サーバー管理者にモジュールのインストールを依頼してください。",
@@ -197,45 +218,35 @@ OC.L10N.register(
     "PostgreSQL >= 9 required" : "PostgreSQL 9以上が必要です",
     "Please upgrade your database version" : "新しいバージョンのデータベースにアップグレードしてください",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
-    "Data directory (%s) is readable by other users" : "データディレクトリ (%s) は他のユーザーも閲覧することができます",
-    "Data directory (%s) must be an absolute path" : "データディレクトリ (%s) は、絶対パスである必要があります。",
+    "Your data directory is readable by other users" : "データディレクトリは、他のユーザーから読み取り専用です",
+    "Your data directory must be an absolute path" : "データディレクトリは、絶対パスにする必要があります",
     "Check the value of \"datadirectory\" in your configuration" : "設定ファイル内の \"datadirectory\" の値を確認してください。",
-    "Data directory (%s) is invalid" : "データディレクトリ (%s) は無効です",
-    "Please check that the data directory contains a file \".ocdata\" in its root." : "データディレクトリに \".ocdata\" ファイルが含まれていることを確認してください。",
+    "Your data directory is invalid" : "データディレクトリが無効です",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "データディレクトリの直下に \".ocdata\" ファイルがあるのを確認してください。",
     "Could not obtain lock type %d on \"%s\"." : "\"%s\" で %d タイプのロックを取得できませんでした。",
     "Storage unauthorized. %s" : "権限のないストレージです。 %s",
     "Storage incomplete configuration. %s" : "設定が未完了のストレージです。 %s",
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
-    "4-byte characters are not supported in file names" : "ファイル名に4バイト文字を使用するのはサポートされていません",
-    "App directory already exists" : "アプリディレクトリはすでに存在します",
-    "Can't create app folder. Please fix permissions. %s" : "アプリフォルダーを作成できませんでした。%s のパーミッションを修正してください。",
-    "Archive does not contain a directory named %s" : "%s という名前のディレクトリは、アーカイブに含まれていません",
-    "No source specified when installing app" : "アプリインストール時のソースが未指定",
-    "No href specified when installing app from http" : "アプリインストール時のhttpの URL が未指定",
-    "No path specified when installing app from local file" : "アプリインストール時のローカルファイルのパスが未指定",
-    "Archives of type %s are not supported" : "\"%s\"タイプのアーカイブ形式は未サポート",
-    "Failed to open archive when installing app" : "アプリをインストール中にアーカイブファイルを開けませんでした。",
-    "App does not provide an info.xml file" : "アプリにinfo.xmlファイルが入っていません",
-    "App cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリがインストールできません。",
-    "Signature could not get checked. Please contact the app developer and check your admin screen." : "署名が確認できませんでした｡このアプリの開発者へ連絡し、管理画面を確認してください。",
-    "App can't be installed because of not allowed code in the App" : "アプリで許可されないコードが入っているのが原因でアプリがインストールできません",
-    "App can't be installed because it is not compatible with this version of the server" : "アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "非shippedアプリには許可されない<shipped>true</shipped>タグが含まれているためにアプリをインストールできません。",
-    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "info.xmlのバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
-    "Logging" : "ロギング",
-    "Recommended" : "おすすめ",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows プラットフォームはサポートしていません。",
-    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself." : "マイクロソフト Windowsプラットフォーム上での Nextcloudの動作をサポートしていません。サーバー丸ごと移行する方式をとれない場合は仮想マシンで Linux を動かすことをお勧めします。",
-    "Storage not available" : "ストレージが利用できません",
-    "ownCloud %s or higher is required." : "ownCloud %s 以上が必要です",
-    "ownCloud %s or lower is required." : "ownCloud %s 以下が必要です",
-    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : "\"%s\" アプリはこのバージョンのNextcloudと互換性がないためインストールできません。",
-    "App can't be installed because it is not compatible with this version of Nextcloud" : "このバージョンのNextcloudと互換性がないため、アプリケーションをインストールできません",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "info.xml/version のバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
-    "Hint: You can speed up the upgrade by executing this SQL command manually: ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;" : "ヒント：次のSQLコマンドを手動で実行すると、アップグレードを高速化できます： ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;",
-    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Microsoft WindowsプラットフォームでのNextcloud Serverの実行はサポートされていません。サーバー自体を移行するオプションがない場合は、仮想マシンでLinuxサーバーを使用することをお勧めします。 <a href=\"%s\"> %s </a>でLinuxパッケージを見つけたり、簡単に仮想マシンイメージを展開したりできます。既存のインストールをLinuxに移行するには、<a href=\"%s\">こちらのドキュメント</a>にいくつかのヒントと移行スクリプトがあります。",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "多くの場合、<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Webサーバーのルートディレクトリに書き込み権限を与える</a>ことで解決できます。"
+    "Personal" : "パーソナル",
+    "Admin" : "管理者",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Encryption" : "暗号化",
+    "Tips & tricks" : "ヒントとコツ",
+    "DB Error: \"%s\"" : "DBエラー: \"%s\"",
+    "Offending command was: \"%s\"" : "問題のあるコマンド: \"%s\"",
+    "Offending command was: \"%s\", name: %s, password: %s" : "問題のあるコマンド: \"%s\", name: %s, password: %s",
+    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "%sのアクセス権を設定できません。%sの権限不足です ",
+    "Setting permissions for %s failed, because the item was not found" : "%sのアクセス権を設定できません。指定されたアイテムがありません ",
+    "Cannot clear expiration date. Shares are required to have an expiration date." : "有効期限は削除できません。共有には有効期限が必要です。",
+    "Cannot increase permissions of %s" : "%sの権限を付与できません ",
+    "Files can't be shared with delete permissions" : "削除権限付きでファイル共有はできません",
+    "Files can't be shared with create permissions" : "作成権限付きでファイル共有はできません",
+    "Cannot set expiration date more than %s days in the future" : "%s 日以上先の有効期限は設定できません ",
+    "No app name specified" : "アプリ名が指定されていません",
+    "App '%s' could not be installed!" : "アプリ名 %s はインストールできませんでした",
+    "Sync clients" : "同期クライアント"
 },
 "nplurals=1; plural=0;");
