@@ -87,7 +87,8 @@ class Mailer implements IMailer {
 	 * @return Message
 	 */
 	public function createMessage() {
-		return new Message(new \Swift_Message());
+		$plainTextOnly = $this->config->getSystemValue('mail_send_plaintext_only', false);
+		return new Message(new \Swift_Message(), $plainTextOnly);
 	}
 
 	/**
