@@ -35,15 +35,10 @@
  */
 namespace OC;
 
-use Assetic\Asset\AssetCollection;
-use Assetic\Asset\FileAsset;
-use Assetic\AssetWriter;
-use Assetic\Filter\CssImportFilter;
-use Assetic\Filter\CssMinFilter;
-use Assetic\Filter\CssRewriteFilter;
-use Assetic\Filter\JSqueezeFilter;
-use Assetic\Filter\SeparatorFilter;
+use OC\Template\JSCombiner;
 use OC\Template\JSConfigHelper;
+use OC\Template\SCSSCacher;
+use OCP\Defaults;
 
 class TemplateLayout extends \OC_Template {
 
@@ -63,6 +58,7 @@ class TemplateLayout extends \OC_Template {
 		// yes - should be injected ....
 		$this->config = \OC::$server->getConfig();
 
+
 		// Decide which page we show
 		if($renderAs == 'user') {
 			parent::__construct( 'core', 'layout.user' );
@@ -99,21 +95,23 @@ class TemplateLayout extends \OC_Template {
 				}
 			}
 			$userDisplayName = \OC_User::getDisplayName();
-			$appsMgmtActive = strpos(\OC::$server->getRequest()->getRequestUri(), \OC::$server->getURLGenerator()->linkToRoute('settings.AppSettings.viewApps')) === 0;
-			if ($appsMgmtActive) {
-				$l = \OC::$server->getL10N('lib');
-				$this->assign('application', $l->t('Apps'));
-			}
 			$this->assign('user_displayname', $userDisplayName);
 			$this->assign('user_uid', \OC_User::getUser());
-			$this->assign('appsmanagement_active', $appsMgmtActive);
-			$this->assign('enableAvatars', $this->config->getSystemValue('enable_avatars', true) === true);
 
 			if (\OC_User::getUser() === false) {
 				$this->assign('userAvatarSet', false);
 			} else {
 				$this->assign('userAvatarSet', \OC::$server->getAvatarManager()->getAvatar(\OC_User::getUser())->exists());
-				$this->assign('userAvatarVersion', \OC::$server->getConfig()->getUserValue(\OC_User::getUser(), 'avatar', 'version', 0));
+				$this->assign('userAvatarVersion', $this->config->getUserValue(\OC_User::getUser(), 'avatar', 'version', 0));
+			}
+
+			// check if app menu icons should be inverted
+			try {
+				/** @var \OCA\Theming\Util $util */
+				$util = \OC::$server->query(\OCA\Theming\Util::class);
+				$this->assign('themingInvertMenu', $util->invertTextColor(\OC::$server->getThemingDefaults()->getColorPrimary()));
+			} catch (\OCP\AppFramework\QueryException $e) {
+				$this->assign('themingInvertMenu', false);
 			}
 
 		} else if ($renderAs == 'error') {
@@ -133,7 +131,7 @@ class TemplateLayout extends \OC_Template {
 			if (empty(self::$versionHash)) {
 				$v = \OC_App::getAppVersions();
 				$v['core'] = implode('.', \OCP\Util::getVersion());
-				self::$versionHash = md5(implode(',', $v));
+				self::$versionHash = substr(md5(implode(',', $v)), 0, 8);
 			}
 		} else {
 			self::$versionHash = md5('not installed');
@@ -145,18 +143,17 @@ class TemplateLayout extends \OC_Template {
 		if ($this->config->getSystemValue('installed', false) && $renderAs != 'error') {
 			if (\OC::$server->getContentSecurityPolicyNonceManager()->browserSupportsCspV3()) {
 				$jsConfigHelper = new JSConfigHelper(
-					\OC::$server->getL10N('core'),
-					\OC::$server->getThemingDefaults(),
+					\OC::$server->getL10N('lib'),
+					\OC::$server->query(Defaults::class),
 					\OC::$server->getAppManager(),
 					\OC::$server->getSession(),
 					\OC::$server->getUserSession()->getUser(),
-					\OC::$server->getConfig(),
+					$this->config,
 					\OC::$server->getGroupManager(),
 					\OC::$server->getIniWrapper(),
 					\OC::$server->getURLGenerator()
 				);
 				$this->assign('inline_ocjs', $jsConfigHelper->getConfig());
-				$this->assign('foo', 'bar');
 			} else {
 				$this->append('jsfiles', \OC::$server->getURLGenerator()->linkToRoute('core.OCJS.getConfig', ['v' => self::$versionHash]));
 			}
@@ -164,11 +161,29 @@ class TemplateLayout extends \OC_Template {
 		foreach($jsFiles as $info) {
 			$web = $info[1];
 			$file = $info[2];
-			$this->append( 'jsfiles', $web.'/'.$file . '?v=' . self::$versionHash);
+			$this->append( 'jsfiles', $web.'/'.$file . $this->getVersionHashSuffix() );
+		}
+
+		try {
+			$pathInfo = \OC::$server->getRequest()->getPathInfo();
+		} catch (\Exception $e) {
+			$pathInfo = '';
+		}
+
+		// Do not initialise scss appdata until we have a fully installed instance
+		// Do not load scss for update, errors, installation or login page
+		if(\OC::$server->getSystemConfig()->getValue('installed', false)
+			&& !\OCP\Util::needUpgrade()
+			&& $pathInfo !== ''
+			&& !preg_match('/^\/login/', $pathInfo)) {
+			$cssFiles = self::findStylesheetFiles(\OC_Util::$styles);
+		} else {
+			// If we ignore the scss compiler,
+			// we need to load the guest css fallback
+			\OC_Util::addStyle('guest');
+			$cssFiles = self::findStylesheetFiles(\OC_Util::$styles, false);
 		}
 
-		// Add the css files
-		$cssFiles = self::findStylesheetFiles(\OC_Util::$styles);
 		$this->assign('cssfiles', array());
 		$this->assign('printcssfiles', []);
 		$this->assign('versionHash', self::$versionHash);
@@ -177,30 +192,95 @@ class TemplateLayout extends \OC_Template {
 			$file = $info[2];
 
 			if (substr($file, -strlen('print.css')) === 'print.css') {
-				$this->append( 'printcssfiles', $web.'/'.$file . '?v=' . self::$versionHash);
+				$this->append( 'printcssfiles', $web.'/'.$file . $this->getVersionHashSuffix() );
 			} else {
-				$this->append( 'cssfiles', $web.'/'.$file . '?v=' . self::$versionHash);
+				$this->append( 'cssfiles', $web.'/'.$file . $this->getVersionHashSuffix($web, $file)  );
 			}
 		}
 	}
 
+	/**
+	 * @param string $path
+ 	 * @param string $file
+	 * @return string
+	 */
+	protected function getVersionHashSuffix($path = false, $file = false) {
+		if ($this->config->getSystemValue('debug', false)) {
+			// allows chrome workspace mapping in debug mode
+			return "";
+		}
+		$themingSuffix = '';
+		$v = [];
+
+		if ($this->config->getSystemValue('installed', false)) {
+			if (\OC::$server->getAppManager()->isInstalled('theming')) {
+				$themingSuffix = '-' . $this->config->getAppValue('theming', 'cachebuster', '0');
+			}
+			$v = \OC_App::getAppVersions();
+		}
+
+		// Try the webroot path for a match
+		if ($path !== false && $path !== '') {
+			$appName = $this->getAppNamefromPath($path);
+			if(array_key_exists($appName, $v)) {
+				$appVersion = $v[$appName];
+				return '?v=' . substr(md5($appVersion), 0, 8) . $themingSuffix;
+			}
+		}
+		// fallback to the file path instead
+		if ($file !== false && $file !== '') {
+			$appName = $this->getAppNamefromPath($file);
+			if(array_key_exists($appName, $v)) {
+				$appVersion = $v[$appName];
+				return '?v=' . substr(md5($appVersion), 0, 8) . $themingSuffix;
+			}
+		}
+
+		return '?v=' . self::$versionHash . $themingSuffix;
+	}
+
 	/**
 	 * @param array $styles
 	 * @return array
 	 */
-	static public function findStylesheetFiles($styles) {
+	static public function findStylesheetFiles($styles, $compileScss = true) {
 		// Read the selected theme from the config file
 		$theme = \OC_Util::getTheme();
 
+		if($compileScss) {
+			$SCSSCacher = \OC::$server->query(SCSSCacher::class);
+		} else {
+			$SCSSCacher = null;
+		}
+
 		$locator = new \OC\Template\CSSResourceLocator(
 			\OC::$server->getLogger(),
 			$theme,
 			array( \OC::$SERVERROOT => \OC::$WEBROOT ),
-			array( \OC::$SERVERROOT => \OC::$WEBROOT ));
+			array( \OC::$SERVERROOT => \OC::$WEBROOT ),
+			$SCSSCacher
+		);
 		$locator->find($styles);
 		return $locator->getResources();
 	}
 
+	/**
+	 * @param string $path
+	 * @return string|boolean
+	 */
+	public function getAppNamefromPath($path) {
+		if ($path !== '' && is_string($path)) {
+			$pathParts = explode('/', $path);
+			if ($pathParts[0] === 'css') {
+				// This is a scss request
+				return $pathParts[1];
+			}
+			return end($pathParts);
+		}
+		return false;
+
+	}
+
 	/**
 	 * @param array $scripts
 	 * @return array
@@ -213,7 +293,14 @@ class TemplateLayout extends \OC_Template {
 			\OC::$server->getLogger(),
 			$theme,
 			array( \OC::$SERVERROOT => \OC::$WEBROOT ),
-			array( \OC::$SERVERROOT => \OC::$WEBROOT ));
+			array( \OC::$SERVERROOT => \OC::$WEBROOT ),
+			new JSCombiner(
+				\OC::$server->getAppDataDir('js'),
+				\OC::$server->getURLGenerator(),
+				\OC::$server->getMemCacheFactory()->create('JS'),
+				\OC::$server->getSystemConfig()
+			)
+			);
 		$locator->find($scripts);
 		return $locator->getResources();
 	}
