@@ -1,6 +1,7 @@
 <?php
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2016, Lukas Reschke <lukas@statuscode.ch>
  *
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bart Visscher <bartv@thisnet.nl>
@@ -47,9 +48,9 @@
  *
  */
 use OC\App\DependencyAnalyzer;
+use OC\App\InfoParser;
 use OC\App\Platform;
 use OC\Installer;
-use OC\OCSClient;
 use OC\Repair;
 use OCP\App\ManagerEvent;
 
@@ -132,10 +133,9 @@ class OC_App {
 	 * load a single app
 	 *
 	 * @param string $app
-	 * @param bool $checkUpgrade whether an upgrade check should be done
-	 * @throws \OC\NeedsUpdateException
+	 * @throws Exception
 	 */
-	public static function loadApp($app, $checkUpgrade = true) {
+	public static function loadApp($app) {
 		self::$loadedApps[] = $app;
 		$appPath = self::getAppPath($app);
 		if($appPath === false) {
@@ -147,10 +147,15 @@ class OC_App {
 
 		if (is_file($appPath . '/appinfo/app.php')) {
 			\OC::$server->getEventLogger()->start('load_app_' . $app, 'Load app: ' . $app);
-			if ($checkUpgrade and self::shouldUpgrade($app)) {
-				throw new \OC\NeedsUpdateException();
+			try {
+				self::requireAppFile($app);
+			} catch (Error $ex) {
+				\OC::$server->getLogger()->logException($ex);
+				if (!\OC::$server->getAppManager()->isShipped($app)) {
+					// Only disable apps which are not shipped
+					self::disable($app);
+				}
 			}
-			self::requireAppFile($app);
 			if (self::isType($app, array('authentication'))) {
 				// since authentication apps affect the "is app enabled for group" check,
 				// the enabled apps cache needs to be cleared to make sure that the
@@ -160,6 +165,23 @@ class OC_App {
 			}
 			\OC::$server->getEventLogger()->end('load_app_' . $app);
 		}
+
+		$info = self::getAppInfo($app);
+		if (!empty($info['activity']['filters'])) {
+			foreach ($info['activity']['filters'] as $filter) {
+				\OC::$server->getActivityManager()->registerFilter($filter);
+			}
+		}
+		if (!empty($info['activity']['settings'])) {
+			foreach ($info['activity']['settings'] as $setting) {
+				\OC::$server->getActivityManager()->registerSetting($setting);
+			}
+		}
+		if (!empty($info['activity']['providers'])) {
+			foreach ($info['activity']['providers'] as $provider) {
+				\OC::$server->getActivityManager()->registerProvider($provider);
+			}
+		}
 	}
 
 	/**
@@ -175,6 +197,7 @@ class OC_App {
 		self::$alreadyRegistered[$key] = true;
 		// Register on PSR-4 composer autoloader
 		$appNamespace = \OC\AppFramework\App::buildAppNamespace($app);
+		\OC::$server->registerNamespace($app, $appNamespace);
 		\OC::$composerAutoloader->addPsr4($appNamespace . '\\', $path . '/lib/', true);
 		if (defined('PHPUNIT_RUN') || defined('CLI_TEST_RUN')) {
 			\OC::$composerAutoloader->addPsr4($appNamespace . '\\Tests\\', $path . '/tests/', true);
@@ -188,18 +211,11 @@ class OC_App {
 	 * Load app.php from the given app
 	 *
 	 * @param string $app app name
+	 * @throws Error
 	 */
 	private static function requireAppFile($app) {
-		try {
-			// encapsulated here to avoid variable scope conflicts
-			require_once $app . '/appinfo/app.php';
-		} catch (Error $ex) {
-			\OC::$server->getLogger()->logException($ex);
-			$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
-			if (!in_array($app, $blacklist)) {
-				self::disable($app);
-			}
-		}
+		// encapsulated here to avoid variable scope conflicts
+		require_once $app . '/appinfo/app.php';
 	}
 
 	/**
@@ -254,9 +270,17 @@ class OC_App {
 			$appTypes = implode(',', $appData['types']);
 		} else {
 			$appTypes = '';
+			$appData['types'] = [];
 		}
 
 		\OC::$server->getAppConfig()->setValue($app, 'types', $appTypes);
+
+		if (\OC::$server->getAppManager()->hasProtectedAppType($appData['types'])) {
+			$enabled = \OC::$server->getAppConfig()->getValue($app, 'enabled', 'yes');
+			if ($enabled !== 'yes' && $enabled !== 'no') {
+				\OC::$server->getAppConfig()->setValue($app, 'enabled', 'yes');
+			}
+		}
 	}
 
 	/**
@@ -325,19 +349,33 @@ class OC_App {
 	/**
 	 * enables an app
 	 *
-	 * @param mixed $app app
+	 * @param string $appId
 	 * @param array $groups (optional) when set, only these groups will have access to the app
 	 * @throws \Exception
 	 * @return void
 	 *
 	 * This function set an app as enabled in appconfig.
 	 */
-	public static function enable($app, $groups = null) {
-		self::$enabledAppsCache = array(); // flush
-		if (!Installer::isInstalled($app)) {
-			$app = self::installApp($app);
+	public function enable($appId,
+						   $groups = null) {
+		self::$enabledAppsCache = []; // flush
+
+		// Check if app is already downloaded
+		$installer = new Installer(
+			\OC::$server->getAppFetcher(),
+			\OC::$server->getHTTPClientService(),
+			\OC::$server->getTempManager(),
+			\OC::$server->getLogger(),
+			\OC::$server->getConfig()
+		);
+		$isDownloaded = $installer->isDownloaded($appId);
+
+		if(!$isDownloaded) {
+			$installer->downloadApp($appId);
 		}
 
+		$installer->installApp($appId);
+
 		$appManager = \OC::$server->getAppManager();
 		if (!is_null($groups)) {
 			$groupManager = \OC::$server->getGroupManager();
@@ -348,38 +386,10 @@ class OC_App {
 					$groupsList[] = $groupManager->get($group);
 				}
 			}
-			$appManager->enableAppForGroups($app, $groupsList);
+			$appManager->enableAppForGroups($appId, $groupsList);
 		} else {
-			$appManager->enableApp($app);
+			$appManager->enableApp($appId);
 		}
-
-		$info = self::getAppInfo($app);
-		if(isset($info['settings']) && is_array($info['settings'])) {
-			$appPath = self::getAppPath($app);
-			self::registerAutoloading($app, $appPath);
-			\OC::$server->getSettingsManager()->setupSettings($info['settings']);
-		}
-	}
-
-	/**
-	 * @param string $app
-	 * @return int
-	 */
-	private static function downloadApp($app) {
-		$ocsClient = new OCSClient(
-			\OC::$server->getHTTPClientService(),
-			\OC::$server->getConfig(),
-			\OC::$server->getLogger()
-		);
-		$appData = $ocsClient->getApplication($app, \OCP\Util::getVersion());
-		$download = $ocsClient->getApplicationDownload($app, \OCP\Util::getVersion());
-		if(isset($download['downloadlink']) and $download['downloadlink']!='') {
-			// Replace spaces in download link without encoding entire URL
-			$download['downloadlink'] = str_replace(' ', '%20', $download['downloadlink']);
-			$info = array('source' => 'http', 'href' => $download['downloadlink'], 'appdata' => $appData);
-			$app = Installer::installApp($info);
-		}
-		return $app;
 	}
 
 	/**
@@ -391,7 +401,14 @@ class OC_App {
 			return false;
 		}
 
-		return Installer::removeApp($app);
+		$installer = new Installer(
+			\OC::$server->getAppFetcher(),
+			\OC::$server->getHTTPClientService(),
+			\OC::$server->getTempManager(),
+			\OC::$server->getLogger(),
+			\OC::$server->getConfig()
+		);
+		return $installer->removeApp($app);
 	}
 
 	/**
@@ -401,11 +418,6 @@ class OC_App {
 	 * @throws Exception
 	 */
 	public static function disable($app) {
-		// Convert OCS ID to regular application identifier
-		if(self::getInternalAppIdByOcs($app) !== false) {
-			$app = self::getInternalAppIdByOcs($app);
-		}
-
 		// flush
 		self::$enabledAppsCache = array();
 
@@ -423,91 +435,8 @@ class OC_App {
 		$appManager->disableApp($app);
 	}
 
-	/**
-	 * Returns the Settings Navigation
-	 *
-	 * @return string[]
-	 *
-	 * This function returns an array containing all settings pages added. The
-	 * entries are sorted by the key 'order' ascending.
-	 */
-	public static function getSettingsNavigation() {
-		$l = \OC::$server->getL10N('lib');
-		$urlGenerator = \OC::$server->getURLGenerator();
-
-		$settings = array();
-		// by default, settings only contain the help menu
-		if (OC_Util::getEditionString() === '' &&
-			\OC::$server->getSystemConfig()->getValue('knowledgebaseenabled', true) == true
-		) {
-			$settings = array(
-				array(
-					"id" => "help",
-					"order" => 1000,
-					"href" => $urlGenerator->linkToRoute('settings_help'),
-					"name" => $l->t("Help"),
-					"icon" => $urlGenerator->imagePath("settings", "help.svg")
-				)
-			);
-		}
-
-		// if the user is logged-in
-		if (OC_User::isLoggedIn()) {
-			// personal menu
-			$settings[] = array(
-				"id" => "personal",
-				"order" => 1,
-				"href" => $urlGenerator->linkToRoute('settings_personal'),
-				"name" => $l->t("Personal"),
-				"icon" => $urlGenerator->imagePath("settings", "personal.svg")
-			);
-
-			//SubAdmins are also allowed to access user management
-			$userObject = \OC::$server->getUserSession()->getUser();
-			$isSubAdmin = false;
-			if($userObject !== null) {
-				$isSubAdmin = \OC::$server->getGroupManager()->getSubAdmin()->isSubAdmin($userObject);
-			}
-			if ($isSubAdmin) {
-				// admin users menu
-				$settings[] = array(
-					"id" => "core_users",
-					"order" => 2,
-					"href" => $urlGenerator->linkToRoute('settings_users'),
-					"name" => $l->t("Users"),
-					"icon" => $urlGenerator->imagePath("settings", "users.svg")
-				);
-			}
-
-			// if the user is an admin
-			if (OC_User::isAdminUser(OC_User::getUser())) {
-				// admin settings
-				$settings[] = array(
-					"id" => "admin",
-					"order" => 1000,
-					"href" => $urlGenerator->linkToRoute('settings.AdminSettings.index'),
-					"name" => $l->t("Admin"),
-					"icon" => $urlGenerator->imagePath("settings", "admin.svg")
-				);
-			}
-		}
-
-		$navigation = self::proceedNavigation($settings);
-		return $navigation;
-	}
-
 	// This is private as well. It simply works, so don't ask for more details
 	private static function proceedNavigation($list) {
-		$activeApp = OC::$server->getNavigationManager()->getActiveEntry();
-		foreach ($list as &$navEntry) {
-			if ($navEntry['id'] == $activeApp) {
-				$navEntry['active'] = true;
-			} else {
-				$navEntry['active'] = false;
-			}
-		}
-		unset($navEntry);
-
 		usort($list, function($a, $b) {
 			if (isset($a['order']) && isset($b['order'])) {
 				return ($a['order'] < $b['order']) ? -1 : 1;
@@ -518,6 +447,16 @@ class OC_App {
 			}
 		});
 
+		$activeApp = OC::$server->getNavigationManager()->getActiveEntry();
+		foreach ($list as $index => &$navEntry) {
+			if ($navEntry['id'] == $activeApp) {
+				$navEntry['active'] = true;
+			} else {
+				$navEntry['active'] = false;
+			}
+		}
+		unset($navEntry);
+
 		return $list;
 	}
 
@@ -548,7 +487,7 @@ class OC_App {
 	 * @param string $appId
 	 * @return false|string
 	 */
-	protected static function findAppInDirectories($appId) {
+	public static function findAppInDirectories($appId) {
 		$sanitizedAppId = self::cleanAppId($appId);
 		if($sanitizedAppId !== $appId) {
 			return false;
@@ -607,18 +546,6 @@ class OC_App {
 		return false;
 	}
 
-
-	/**
-	 * check if an app's directory is writable
-	 *
-	 * @param string $appId
-	 * @return bool
-	 */
-	public static function isAppDirWritable($appId) {
-		$path = self::getAppPath($appId);
-		return ($path !== false) ? is_writable($path) : false;
-	}
-
 	/**
 	 * Get the path for the given app on the access
 	 * If the app is defined in multiple directories, the first one is taken. (false if not found)
@@ -637,13 +564,16 @@ class OC_App {
 	 * get the last version of the app from appinfo/info.xml
 	 *
 	 * @param string $appId
+	 * @param bool $useCache
 	 * @return string
 	 */
-	public static function getAppVersion($appId) {
-		if (!isset(self::$appVersion[$appId])) {
-			$file = self::getAppPath($appId);
-			self::$appVersion[$appId] = ($file !== false) ? self::getAppVersionByPath($file) : '0';
+	public static function getAppVersion($appId, $useCache = true) {
+		if($useCache && isset(self::$appVersion[$appId])) {
+			return self::$appVersion[$appId];
 		}
+
+		$file = self::getAppPath($appId);
+		self::$appVersion[$appId] = ($file !== false) ? self::getAppVersionByPath($file) : '0';
 		return self::$appVersion[$appId];
 	}
 
@@ -683,7 +613,7 @@ class OC_App {
 			$file = $appPath . '/appinfo/info.xml';
 		}
 
-		$parser = new \OC\App\InfoParser(\OC::$server->getURLGenerator());
+		$parser = new InfoParser(\OC::$server->getMemCacheFactory()->create('core.appinfo'));
 		$data = $parser->parse($file);
 
 		if (is_array($data)) {
@@ -715,8 +645,20 @@ class OC_App {
 	 */
 	public static function getNavigation() {
 		$entries = OC::$server->getNavigationManager()->getAll();
-		$navigation = self::proceedNavigation($entries);
-		return $navigation;
+		return self::proceedNavigation($entries);
+	}
+
+	/**
+	 * Returns the Settings Navigation
+	 *
+	 * @return string[]
+	 *
+	 * This function returns an array containing all settings pages added. The
+	 * entries are sorted by the key 'order' ascending.
+	 */
+	public static function getSettingsNavigation() {
+		$entries = OC::$server->getNavigationManager()->getAll('settings');
+		return self::proceedNavigation($entries);
 	}
 
 	/**
@@ -831,24 +773,16 @@ class OC_App {
 	/**
 	 * List all apps, this is used in apps.php
 	 *
-	 * @param bool $onlyLocal
-	 * @param bool $includeUpdateInfo Should we check whether there is an update
-	 *                                in the app store?
-	 * @param OCSClient $ocsClient
 	 * @return array
 	 */
-	public static function listAllApps($onlyLocal = false,
-									   $includeUpdateInfo = true,
-									   OCSClient $ocsClient) {
+	public function listAllApps() {
 		$installedApps = OC_App::getAllApps();
 
-		//TODO which apps do we want to blacklist and how do we integrate
-		// blacklisting with the multi apps folder feature?
-
 		//we don't want to show configuration for these
 		$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
 		$appList = array();
 		$langCode = \OC::$server->getL10N('core')->getLanguageCode();
+		$urlGenerator = \OC::$server->getURLGenerator();
 
 		foreach ($installedApps as $app) {
 			if (array_search($app, $blacklist) === false) {
@@ -886,8 +820,6 @@ class OC_App {
 					$info['removable'] = true;
 				}
 
-				$info['update'] = ($includeUpdateInfo) ? Installer::isUpdateAvailable($app) : null;
-
 				$appPath = self::getAppPath($app);
 				if($appPath !== false) {
 					$appIcon = $appPath . '/img/' . $app . '.svg';
@@ -902,33 +834,25 @@ class OC_App {
 						}
 					}
 				}
+				// fix documentation
+				if (isset($info['documentation']) && is_array($info['documentation'])) {
+					foreach ($info['documentation'] as $key => $url) {
+						// If it is not an absolute URL we assume it is a key
+						// i.e. admin-ldap will get converted to go.php?to=admin-ldap
+						if (stripos($url, 'https://') !== 0 && stripos($url, 'http://') !== 0) {
+							$url = $urlGenerator->linkToDocs($url);
+						}
+
+						$info['documentation'][$key] = $url;
+					}
+				}
+
 				$info['version'] = OC_App::getAppVersion($app);
 				$appList[] = $info;
 			}
 		}
-		if ($onlyLocal) {
-			$remoteApps = [];
-		} else {
-			$remoteApps = OC_App::getAppstoreApps('approved', null, $ocsClient);
-		}
-		if ($remoteApps) {
-			// Remove duplicates
-			foreach ($appList as $app) {
-				foreach ($remoteApps AS $key => $remote) {
-					if ($app['name'] === $remote['name'] ||
-						(isset($app['ocsid']) &&
-							$app['ocsid'] === $remote['id'])
-					) {
-						unset($remoteApps[$key]);
-					}
-				}
-			}
-			$combinedApps = array_merge($appList, $remoteApps);
-		} else {
-			$combinedApps = $appList;
-		}
 
-		return $combinedApps;
+		return $appList;
 	}
 
 	/**
@@ -946,70 +870,6 @@ class OC_App {
 		return false;
 	}
 
-	/**
-	 * Get a list of all apps on the appstore
-	 * @param string $filter
-	 * @param string|null $category
-	 * @param OCSClient $ocsClient
-	 * @return array|bool  multi-dimensional array of apps.
-	 *                     Keys: id, name, type, typename, personid, license, detailpage, preview, changed, description
-	 */
-	public static function getAppstoreApps($filter = 'approved',
-										   $category = null,
-										   OCSClient $ocsClient) {
-		$categories = [$category];
-
-		if (is_null($category)) {
-			$categoryNames = $ocsClient->getCategories(\OCP\Util::getVersion());
-			if (is_array($categoryNames)) {
-				// Check that categories of apps were retrieved correctly
-				if (!$categories = array_keys($categoryNames)) {
-					return false;
-				}
-			} else {
-				return false;
-			}
-		}
-
-		$page = 0;
-		$remoteApps = $ocsClient->getApplications($categories, $page, $filter, \OCP\Util::getVersion());
-		$apps = [];
-		$i = 0;
-		$l = \OC::$server->getL10N('core');
-		foreach ($remoteApps as $app) {
-			$potentialCleanId = self::getInternalAppIdByOcs($app['id']);
-			// enhance app info (for example the description)
-			$apps[$i] = OC_App::parseAppInfo($app);
-			$apps[$i]['author'] = $app['personid'];
-			$apps[$i]['ocs_id'] = $app['id'];
-			$apps[$i]['internal'] = 0;
-			$apps[$i]['active'] = ($potentialCleanId !== false) ? self::isEnabled($potentialCleanId) : false;
-			$apps[$i]['update'] = false;
-			$apps[$i]['groups'] = false;
-			$apps[$i]['score'] = $app['score'];
-			$apps[$i]['removable'] = false;
-			if ($app['label'] == 'recommended') {
-				$apps[$i]['internallabel'] = (string)$l->t('Recommended');
-				$apps[$i]['internalclass'] = 'recommendedapp';
-			}
-
-			// Apps from the appstore are always assumed to be compatible with the
-			// the current release as the initial filtering is done on the appstore
-			$apps[$i]['dependencies']['owncloud']['@attributes']['min-version'] = implode('.', \OCP\Util::getVersion());
-			$apps[$i]['dependencies']['owncloud']['@attributes']['max-version'] = implode('.', \OCP\Util::getVersion());
-
-			$i++;
-		}
-
-
-
-		if (empty($apps)) {
-			return false;
-		} else {
-			return $apps;
-		}
-	}
-
 	public static function shouldUpgrade($app) {
 		$versions = self::getAppVersions();
 		$currentVersion = OC_App::getAppVersion($app);
@@ -1063,7 +923,9 @@ class OC_App {
 	public static function isAppCompatible($ocVersion, $appInfo) {
 		$requireMin = '';
 		$requireMax = '';
-		if (isset($appInfo['dependencies']['owncloud']['@attributes']['min-version'])) {
+		if (isset($appInfo['dependencies']['nextcloud']['@attributes']['min-version'])) {
+			$requireMin = $appInfo['dependencies']['nextcloud']['@attributes']['min-version'];
+		} elseif (isset($appInfo['dependencies']['owncloud']['@attributes']['min-version'])) {
 			$requireMin = $appInfo['dependencies']['owncloud']['@attributes']['min-version'];
 		} else if (isset($appInfo['requiremin'])) {
 			$requireMin = $appInfo['requiremin'];
@@ -1071,7 +933,9 @@ class OC_App {
 			$requireMin = $appInfo['require'];
 		}
 
-		if (isset($appInfo['dependencies']['owncloud']['@attributes']['max-version'])) {
+		if (isset($appInfo['dependencies']['nextcloud']['@attributes']['max-version'])) {
+			$requireMax = $appInfo['dependencies']['nextcloud']['@attributes']['max-version'];
+		} elseif (isset($appInfo['dependencies']['owncloud']['@attributes']['max-version'])) {
 			$requireMax = $appInfo['dependencies']['owncloud']['@attributes']['max-version'];
 		} else if (isset($appInfo['requiremax'])) {
 			$requireMax = $appInfo['requiremax'];
@@ -1112,46 +976,16 @@ class OC_App {
 
 	/**
 	 * @param string $app
+	 * @param \OCP\IConfig $config
+	 * @param \OCP\IL10N $l
 	 * @return bool
+	 *
 	 * @throws Exception if app is not compatible with this version of ownCloud
 	 * @throws Exception if no app-name was specified
 	 */
-	public static function installApp($app) {
-		$appName = $app; // $app will be overwritten, preserve name for error logging
-		$l = \OC::$server->getL10N('core');
-		$config = \OC::$server->getConfig();
-		$ocsClient = new OCSClient(
-			\OC::$server->getHTTPClientService(),
-			$config,
-			\OC::$server->getLogger()
-		);
-		$appData = $ocsClient->getApplication($app, \OCP\Util::getVersion());
-
-		// check if app is a shipped app or not. OCS apps have an integer as id, shipped apps use a string
-		if (!is_numeric($app)) {
-			$shippedVersion = self::getAppVersion($app);
-			if ($appData && version_compare($shippedVersion, $appData['version'], '<')) {
-				$app = self::downloadApp($app);
-			} else {
-				$app = Installer::installShippedApp($app);
-			}
-		} else {
-			// Maybe the app is already installed - compare the version in this
-			// case and use the local already installed one.
-			// FIXME: This is a horrible hack. I feel sad. The god of code cleanness may forgive me.
-			$internalAppId = self::getInternalAppIdByOcs($app);
-			if($internalAppId !== false) {
-				if($appData && version_compare(\OC_App::getAppVersion($internalAppId), $appData['version'], '<')) {
-					$app = self::downloadApp($app);
-				} else {
-					self::enable($internalAppId);
-					$app = $internalAppId;
-				}
-			} else {
-				$app = self::downloadApp($app);
-			}
-		}
-
+	public function installApp($app,
+							   \OCP\IConfig $config,
+							   \OCP\IL10N $l) {
 		if ($app !== false) {
 			// check if the app is compatible with this version of ownCloud
 			$info = self::getAppInfo($app);
@@ -1173,16 +1007,7 @@ class OC_App {
 			}
 
 			// check for required dependencies
-			$dependencyAnalyzer = new DependencyAnalyzer(new Platform($config), $l);
-			$missing = $dependencyAnalyzer->analyze($info);
-			if (!empty($missing)) {
-				$missingMsg = join(PHP_EOL, $missing);
-				throw new \Exception(
-					$l->t('App "%s" cannot be installed because the following dependencies are not fulfilled: %s',
-						array($info['name'], $missingMsg)
-					)
-				);
-			}
+			self::checkAppDependencies($config, $l, $info);
 
 			$config->setAppValue($app, 'enabled', 'yes');
 			if (isset($appData['id'])) {
@@ -1228,13 +1053,12 @@ class OC_App {
 		unset(self::$appVersion[$appId]);
 		// run upgrade code
 		if (file_exists($appPath . '/appinfo/update.php')) {
-			self::loadApp($appId, false);
+			self::loadApp($appId);
 			include $appPath . '/appinfo/update.php';
 		}
+		self::registerAutoloading($appId, $appPath);
 		self::setupBackgroundJobs($appData['background-jobs']);
 		if(isset($appData['settings']) && is_array($appData['settings'])) {
-			$appPath = self::getAppPath($appId);
-			self::registerAutoloading($appId, $appPath);
 			\OC::$server->getSettingsManager()->setupSettings($appData['settings']);
 		}
 
@@ -1273,7 +1097,7 @@ class OC_App {
 			return;
 		}
 		// load the app
-		self::loadApp($appId, false);
+		self::loadApp($appId);
 
 		$dispatcher = OC::$server->getEventDispatcher();
 
@@ -1317,7 +1141,7 @@ class OC_App {
 	 */
 	public static function getStorage($appId) {
 		if (OC_App::isEnabled($appId)) { //sanity check
-			if (OC_User::isLoggedIn()) {
+			if (\OC::$server->getUserSession()->isLoggedIn()) {
 				$view = new \OC\Files\View('/' . OC_User::getUser());
 				if (!$view->file_exists($appId)) {
 					$view->mkdir($appId);
@@ -1394,35 +1218,32 @@ class OC_App {
 			$data['summary'] = self::findBestL10NOption($data['summary'], $lang);
 		}
 		if ($lang && isset($data['description']) && is_array($data['description'])) {
-			$data['description'] = self::findBestL10NOption($data['description'], $lang);
-		}
-
-		// just modify the description if it is available
-		// otherwise this will create a $data element with an empty 'description'
-		if (isset($data['description'])) {
-			if (is_string($data['description'])) {
-				// sometimes the description contains line breaks and they are then also
-				// shown in this way in the app management which isn't wanted as HTML
-				// manages line breaks itself
-
-				// first of all we split on empty lines
-				$paragraphs = preg_split("!\n[[:space:]]*\n!mu", $data['description']);
-
-				$result = [];
-				foreach ($paragraphs as $value) {
-					// replace multiple whitespace (tabs, space, newlines) inside a paragraph
-					// with a single space - also trims whitespace
-					$result[] = trim(preg_replace('![[:space:]]+!mu', ' ', $value));
-				}
-
-				// join the single paragraphs with a empty line in between
-				$data['description'] = implode("\n\n", $result);
-
-			} else {
-				$data['description'] = '';
-			}
+			$data['description'] = trim(self::findBestL10NOption($data['description'], $lang));
+		} else if (isset($data['description']) && is_string($data['description'])) {
+			$data['description'] = trim($data['description']);
+		} else  {
+			$data['description'] = '';
 		}
 
 		return $data;
 	}
+
+	/**
+	 * @param \OCP\IConfig $config
+	 * @param \OCP\IL10N $l
+	 * @param array $info
+	 * @throws \Exception
+	 */
+	public static function checkAppDependencies($config, $l, $info) {
+		$dependencyAnalyzer = new DependencyAnalyzer(new Platform($config), $l);
+		$missing = $dependencyAnalyzer->analyze($info);
+		if (!empty($missing)) {
+			$missingMsg = join(PHP_EOL, $missing);
+			throw new \Exception(
+				$l->t('App "%s" cannot be installed because the following dependencies are not fulfilled: %s',
+					[$info['name'], $missingMsg]
+				)
+			);
+		}
+	}
 }
