@@ -1,100 +1,66 @@
 OC.L10N.register(
     "settings",
     {
-    "Enabled" : "Увімкнено",
-    "Not enabled" : "Вимкнено",
+    "{actor} changed your password" : "{actor} змінив ваш пароль",
+    "{actor} changed your email address" : "{actor} змінив вашу email адресу",
+    "You changed your email address" : "Ви змінили вашу email адресу",
+    "Your email address was changed by an administrator" : "Ваша email адреса змінена адміністратором",
+    "Security" : "Безпека",
+    "Couldn't remove app." : "Неможливо видалити додаток.",
+    "Couldn't update app." : "Не вдалося оновити додаток. ",
     "Wrong password" : "Невірний пароль",
     "Saved" : "Збережено",
     "No user supplied" : "Користувача не вказано",
     "Unable to change password" : "Неможливо змінити пароль",
     "Authentication error" : "Помилка автентифікації",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "Будь ласка введіть пароль відновлення адміністратора, інакше всі дані будуть втрачені",
     "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
-    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend не підтримує зміну паролів, але користувацький ключ шифрування було успішно змінено",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "встановлення та оновлення додатків через магазин додатків або Об’єднання хмарних сховищ",
     "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
     "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL використовує застарілу версію %s (%s). Будь ласка, поновіть вашу операційну систему або функції, такі як %s не працюватимуть надійно.",
-    "A problem occurred, please check your log files (Error: %s)" : "Виникла проблема, будь ласка, перевірте свої файли журналів (Помилка: %s)",
-    "Migration Completed" : "Міграцію завершено",
-    "Group already exists." : "Група вже існує.",
-    "Unable to add group." : "Неможливо додати групу.",
-    "Unable to delete group." : "Неможливо видалити групу.",
-    "test email settings" : "тест налаштувань електронної пошти",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Під час надсилання email сталася помилка. Будь ласка перевірте налаштування. (Помилка: %s)",
-    "Email sent" : "Лист надіслано",
     "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
-    "Invalid request" : "Некоректний запит",
     "Invalid mail address" : "Неправильна email адреса",
-    "A user with that name already exists." : "Користувач з таким іменем вже існує.",
-    "Unable to create user." : "Неможливо створити користувача.",
-    "Your %s account was created" : "Ваш %s аккаунт створений",
-    "Unable to delete user." : "Неможливо видалити користувача.",
+    "Settings saved" : "Налаштування збережено",
     "Unable to change full name" : "Неможливо змінити повне ім'я",
-    "Your full name has been changed." : "Ваше повне ім'я було змінено",
-    "Forbidden" : "Заборонено",
-    "Invalid user" : "Неправильний користувач",
-    "Unable to change mail address" : "Неможливо поміняти email адресу",
-    "Email saved" : "Адресу збережено",
-    "Couldn't remove app." : "Неможливо видалити додаток.",
-    "Admins can't remove themself from the admin group" : "Адміністратор не може видалити себе з групи адміністраторів",
-    "Unable to add user to group %s" : "Не вдалося додати користувача у групу %s",
-    "Unable to remove user from group %s" : "Не вдалося видалити користувача із групи %s",
-    "Couldn't update app." : "Не вдалося оновити додаток. ",
-    "Add trusted domain" : "Додати довірений домен",
+    "Unable to change email address" : "Неможливо змінити електронну адресу",
+    "Your %s account was created" : "Ваш %s аккаунт створений",
     "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
     "Migration started …" : "Міграцію розпочато ...",
-    "Sending..." : "Надсилання...",
-    "Official" : "Офіційні",
-    "All" : "Всі",
-    "Update to %s" : "Оновити до %s",
-    "No apps found for your version" : "Немає застосунків для вашої версії",
-    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Схвалені додатки розроблені довіреними розробниками і пройшли незалежну перевірку безпеки. Їх активно супроводжують у репозиторії з відкритим кодом, а їх розробники стежать, щоб вони були стабільні й прийнятні для повсякденного використання.",
-    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ця програма не перевірена на вразливості безпеки і є новою або нестабільною. Встановлюйте її на власний ризик.",
-    "Please wait...." : "Зачекайте, будь ласка...",
-    "Error while disabling app" : "Помилка вимикання додатка",
-    "Disable" : "Вимкнути",
-    "Enable" : "Увімкнути",
-    "Error while enabling app" : "Помилка вмикання додатка",
-    "Updating...." : "Оновлюється...",
-    "Error while updating app" : "Помилка при оновленні додатку",
-    "Updated" : "Оновлено",
-    "Uninstalling ...." : "Видалення...",
-    "Error while uninstalling app" : "Помилка видалення додатка",
-    "Uninstall" : "Видалити",
-    "App update" : "Оновлення додатку",
-    "Approved" : "Схвалені",
-    "Experimental" : "Експериментальні",
+    "Email sent" : "Лист надіслано",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
     "Valid until {date}" : "Дійсно до {date}",
     "Delete" : "Видалити",
-    "Select a profile picture" : "Обрати зображення облікового запису",
     "Very weak password" : "Дуже слабкий пароль",
     "Weak password" : "Слабкий пароль",
     "So-so password" : "Такий собі пароль",
     "Good password" : "Добрий пароль",
     "Strong password" : "Надійний пароль",
+    "Select a profile picture" : "Обрати зображення облікового запису",
     "Groups" : "Групи",
-    "Unable to delete {objName}" : "Не вдалося видалити {objName}",
-    "A valid group name must be provided" : "Потрібно задати вірне ім'я групи",
-    "deleted {groupName}" : "видалено {groupName}",
-    "undo" : "відмінити",
-    "never" : "ніколи",
-    "deleted {userName}" : "видалено {userName}",
-    "Changing the password will result in data loss, because data recovery is not available for this user" : "Зміна пароля призведе до втрати даних, тому що відновлення даних не доступно для цього користувача",
-    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
-    "A valid password must be provided" : "Потрібно задати вірний пароль",
-    "A valid email must be provided" : "Вкажіть дійсний email",
-    "__language_name__" : "Українська",
+    "Official" : "Офіційні",
+    "User documentation" : "Користувацька документація",
+    "Developer documentation" : "Документація для розробників",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ця програма не може бути встановлено, так як наступні залежності не будуть виконані:",
+    "Enable" : "Увімкнути",
+    "Settings" : "Налаштування",
+    "Email" : "E-mail",
+    "Language" : "Мова",
     "Unlimited" : "Необмежено",
-    "Personal info" : "Особиста інформація",
-    "Sync clients" : "Клієнти синхронізації",
+    "Admins" : "Адміністратори",
+    "Everyone" : "Всі",
+    "Common Name" : "Ім'я:",
+    "Valid until" : "Дійсно до",
+    "Issued By" : "Виданий",
+    "Valid until %s" : "Дійсно до %s",
+    "Import root certificate" : "Імпортувати кореневий сертифікат",
+    "Administrator documentation" : "Документація адміністратора",
+    "Forum" : "Форум",
     "None" : "Жоден",
     "Login" : "Логін",
     "Plain" : "Звичайний",
     "NT LAN Manager" : "Менеджер NT LAN",
     "Email server" : "Сервер електронної пошти",
     "Open documentation" : "Відкрити документацію",
-    "This is used for sending out notifications." : "Використовується для відсилання повідомлень.",
     "Send mode" : "Режим надсилання",
     "Encryption" : "Шифрування",
     "From address" : "Адреса відправника",
@@ -116,24 +82,9 @@ OC.L10N.register(
     "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
     "Start migration" : "Розпочати міграцію",
     "Security & setup warnings" : "Попередження безпеки та налаштування",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Тільки перегляд був включений. Це запобігає встановити деякі конфігурації через веб-інтерфейс. Крім того, файл повинен бути доступний для запису вручну для кожного оновлення.",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на вичищення блоків вбудованої документації. Це зробить кілька основних додатків недоступними.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модуль 'fileinfo' відсутній. Ми наполегливо рекомендуємо увімкнути цей модуль, щоб отримати кращі результати при виявленні MIME-типів.",
-    "System locale can not be set to a one which supports UTF-8." : "Неможливо встановити системну локаль, яка б підтримувала UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "Це означає, що можуть виникати проблеми з деякими символами в іменах файлів.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Пропонуємо встановити необхідні пакети для вашої системи для підтримки однієї з наступних мов %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Якщо ваша копія ownCloud встановлена не в корені домену та використовує систему планування CRON, можливі проблеми з генерацією правильних URL. Щоб уникнути цього, встановіть опцію \"overwrite.cli.url\" файлу config.php відповідно до теки розташування установки (Ймовірніше за все, це \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не вдалося запустити завдання планувальника через CLI. Відбулися наступні технічні помилки:",
     "All checks passed." : "Всі перевірки пройдено.",
-    "Cron" : "Планувальник Cron",
-    "Last cron job execution: %s." : "Останнє виконане Cron завдання: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Останнє виконане Cron завдання: %s. Щось здається неправильним.",
-    "Cron was not executed yet!" : "Cron-задачі ще не запускалися!",
-    "Execute one task with each page loaded" : "Виконати одне завдання для кожної завантаженої сторінки ",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php зареєстрований в службі webcron та буде викликатися кожні 15 хвилин через HTTP.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Використовувати системний cron для виклику cron.php кожні 15 хвилин.",
     "Version" : "Версія",
+    "Execute one task with each page loaded" : "Виконати одне завдання для кожної завантаженої сторінки ",
     "Sharing" : "Спільний доступ",
     "Allow apps to use the Share API" : "Дозволити програмам використовувати API спільного доступу",
     "Allow users to share via link" : "Дозволити користувачам ділитися через посилання",
@@ -147,34 +98,6 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Дозволити користувачам відкривати спільний доступ лише для користувачів з їхньої групи",
     "Exclude groups from sharing" : "Виключити групи зі спільного доступу",
     "These groups will still be able to receive shares, but not to initiate them." : "Ці групи зможуть отримувати спільні файли, але не зможуть відправляти їх.",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Дозволи автодоповнення імені користувача в діалозі спільного доступу. Якщо вимкнено - треба буде вводити повне ім’я користувача.",
-    "Tips & tricks" : "Поради і трюки",
-    "How to do backups" : "Як робити резервне копіювання",
-    "Advanced monitoring" : "Розширений моніторинг",
-    "Performance tuning" : "Налаштування продуктивності",
-    "Improving the config.php" : "Покращення  config.php",
-    "Theming" : "Оформлення",
-    "Hardening and security guidance" : "Інструктування з безпеки та захисту",
-    "Developer documentation" : "Документація для розробників",
-    "Documentation:" : "Документація:",
-    "User documentation" : "Користувацька документація",
-    "Admin documentation" : "Документація адміністратора",
-    "Show description …" : "Показати деталі ...",
-    "Hide description …" : "Сховати деталі ...",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ця програма не може бути встановлено, так як наступні залежності не будуть виконані:",
-    "Enable only for specific groups" : "Включити тільки для конкретних груп",
-    "Uninstall App" : "Видалити додаток",
-    "Common Name" : "Ім'я:",
-    "Valid until" : "Дійсно до",
-    "Issued By" : "Виданий",
-    "Valid until %s" : "Дійсно до %s",
-    "Import root certificate" : "Імпортувати кореневий сертифікат",
-    "Cheers!" : "Будьмо!",
-    "Administrator documentation" : "Документація адміністратора",
-    "Online documentation" : "Документація онлайн",
-    "Forum" : "Форум",
-    "Commercial support" : "Комерційна підтримка",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong> з <strong>%s</strong>",
     "Profile picture" : "Зображення облікового запису",
     "Upload new" : "Завантажити нове",
     "Remove image" : "Видалити зображення",
@@ -182,68 +105,85 @@ OC.L10N.register(
     "Choose as profile picture" : "Обрати як зображення для профілю",
     "Full name" : "Повне ім'я",
     "No display name set" : "Коротке ім'я не вказано",
-    "Email" : "E-mail",
     "Your email address" : "Ваша адреса електронної пошти",
     "No email address set" : "E-mail не вказано",
-    "You are member of the following groups:" : "Ви є членом наступних груп:",
+    "Phone number" : "Номер телефону",
+    "Your phone number" : "Ваш номер телефону",
+    "Address" : "Адреса",
+    "Help translate" : "Допомогти з перекладом",
     "Password" : "Пароль",
     "Current password" : "Поточний пароль",
     "New password" : "Новий пароль",
     "Change password" : "Змінити пароль",
-    "Language" : "Мова",
-    "Help translate" : "Допомогти з перекладом",
-    "Get the apps to sync your files" : "Отримати додатки для синхронізації ваших файлів",
-    "Desktop client" : "Клієнт для ПК",
-    "Android app" : "Android-додаток",
-    "iOS app" : "iOS додаток",
-    "Show First Run Wizard again" : "Показувати Майстер Налаштувань знову",
-    "Name" : "Ім’я",
     "Username" : "Ім'я користувача",
     "Done" : "Готово",
+    "A problem occurred, please check your log files (Error: %s)" : "Виникла проблема, будь ласка, перевірте свої файли журналів (Помилка: %s)",
+    "Migration Completed" : "Міграцію завершено",
+    "Group already exists." : "Група вже існує.",
+    "Unable to add group." : "Неможливо додати групу.",
+    "Unable to delete group." : "Неможливо видалити групу.",
+    "A user with that name already exists." : "Користувач з таким іменем вже існує.",
+    "Unable to create user." : "Неможливо створити користувача.",
+    "Unable to delete user." : "Неможливо видалити користувача.",
+    "Your full name has been changed." : "Ваше повне ім'я було змінено",
+    "Forbidden" : "Заборонено",
+    "Invalid user" : "Неправильний користувач",
+    "Unable to change mail address" : "Неможливо поміняти email адресу",
+    "Email saved" : "Адресу збережено",
+    "Add trusted domain" : "Додати довірений домен",
+    "All" : "Всі",
+    "Update to %s" : "Оновити до %s",
+    "No apps found for your version" : "Немає застосунків для вашої версії",
+    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Схвалені додатки розроблені довіреними розробниками і пройшли незалежну перевірку безпеки. Їх активно супроводжують у репозиторії з відкритим кодом, а їх розробники стежать, щоб вони були стабільні й прийнятні для повсякденного використання.",
+    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Ця програма не перевірена на вразливості безпеки і є новою або нестабільною. Встановлюйте її на власний ризик.",
+    "Error while disabling app" : "Помилка вимикання додатка",
+    "Disable" : "Вимкнути",
+    "Error while enabling app" : "Помилка вмикання додатка",
+    "Updated" : "Оновлено",
+    "Approved" : "Схвалені",
+    "Experimental" : "Експериментальні",
+    "Unable to delete {objName}" : "Не вдалося видалити {objName}",
+    "A valid group name must be provided" : "Потрібно задати вірне ім'я групи",
+    "deleted {groupName}" : "видалено {groupName}",
+    "undo" : "відмінити",
+    "never" : "ніколи",
+    "deleted {userName}" : "видалено {userName}",
+    "Changing the password will result in data loss, because data recovery is not available for this user" : "Зміна пароля призведе до втрати даних, тому що відновлення даних не доступно для цього користувача",
+    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
+    "A valid password must be provided" : "Потрібно задати вірний пароль",
+    "A valid email must be provided" : "Вкажіть дійсний email",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Тільки перегляд був включений. Це запобігає встановити деякі конфігурації через веб-інтерфейс. Крім того, файл повинен бути доступний для запису вручну для кожного оновлення.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
+    "System locale can not be set to a one which supports UTF-8." : "Неможливо встановити системну локаль, яка б підтримувала UTF-8.",
+    "Tips & tricks" : "Поради і трюки",
+    "How to do backups" : "Як робити резервне копіювання",
+    "Performance tuning" : "Налаштування продуктивності",
+    "Improving the config.php" : "Покращення  config.php",
+    "Theming" : "Оформлення",
+    "Hardening and security guidance" : "Інструктування з безпеки та захисту",
+    "Documentation:" : "Документація:",
+    "Admin documentation" : "Документація адміністратора",
+    "Show description …" : "Показати деталі ...",
+    "Hide description …" : "Сховати деталі ...",
+    "Enable only for specific groups" : "Включити тільки для конкретних груп",
+    "Online documentation" : "Документація онлайн",
+    "Commercial support" : "Комерційна підтримка",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong> з <strong>%s</strong>",
+    "You are member of the following groups:" : "Ви є членом наступних груп:",
     "Show storage location" : "Показати місцезнаходження сховища",
-    "Show last log in" : "Показати останній вхід в систему",
     "Show user backend" : "Показати користувача",
-    "Send email to new user" : "Надіслати email новому користувачу",
     "Show email address" : "Показати адресу електронної пошти",
+    "Send email to new user" : "Надіслати email новому користувачу",
     "E-Mail" : "Адреса електронної пошти",
     "Create" : "Створити",
     "Admin Recovery Password" : "Пароль адміністратора для відновлення",
     "Enter the recovery password in order to recover the users files during password change" : "Введіть пароль для того, щоб відновити файли користувачів при зміні паролю",
-    "Everyone" : "Всі",
-    "Admins" : "Адміністратори",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Будь ласка, вкажіть розмір сховища (наприклад: \"512 MB\" або \"12 GB\")",
     "Other" : "Інше",
     "Quota" : "Квота",
     "change full name" : "змінити ім'я",
     "set new password" : "встановити новий пароль",
     "change email address" : "Змінити адресу електронної пошти",
-    "Default" : "За замовчуванням",
-    "log-level out of allowed range" : "рівень протоколювання перевищує дозволені межі",
-    "Language changed" : "Мову змінено",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ви дійсно бажаєте додати \"{domain}\" як довірений домен?",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Усі (критичні проблеми, помилки, попередження, інформаційні, налагодження)",
-    "Info, warnings, errors and fatal issues" : "Інформаційні, попередження, помилки та критичні проблеми",
-    "Warnings, errors and fatal issues" : "Попередження, помилки та критичні проблеми",
-    "Errors and fatal issues" : "Помилки та критичні проблеми",
-    "Fatal issues only" : "Тільки критичні проблеми",
-    "Log" : "Журнал",
-    "Download logfile" : "Завантажити файл журналу",
-    "More" : "Більше",
-    "Less" : "Менше",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Файл журналу - більше 100 МБ. Його завантаження може зайняти деякий час!",
-    "Allow users to send mail notification for shared files" : "Дозволити користувачам сповіщати листами про спільний доступ до файлів",
-    "Allow users to send mail notification for shared files to other users" : "Дозволити користувачам сповіщати листами про спільний доступ до файлів",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "В якості бази даних використовується SQLite. Для великих установок ми рекомендуємо перейти на інший тип серверу баз даних.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особливо сумнівне використання SQLite при синхронізації файлів з використанням клієнта для ПК.",
-    "Experimental applications ahead" : "Спершу експериментальні додатки",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Експериментальні додатки не перевірені на наявність проблем безпеки, нові або нестабільні і в процесі активної розробки. Встановлення їх може спричинити втрату даних або дірки в безпеці.",
-    "Enable experimental apps" : "Увімкнути експериментальні застосунки",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Агов,<br><br>просто щоб ви знали, у вас є аккаунт %s.<br><br>Ваше ім'я користувача: %s<br>Перейдіть сюди: <a href=\"%s\">%s</a><br><br>",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Агов,\n\nпросто щоб ви знали, у вас є аккаунт %s.\n\nВаше ім'я користувача: %s\nПерейдіть сюди: %s\n\n",
-    "Group" : "Група",
-    "Redis" : "Redis",
-    "External Storage" : "Зовнішні сховища",
-    "Updates" : "Оновлення",
-    "An error occurred: {message}" : "Сталася помилка: {message}"
+    "Default" : "За замовчуванням"
 },
-"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
+"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
